// Explorer.cpp : Defines the exported functions for the DLL application.
//

#define STRICT
#define ORBITER_MODULE
#include "orbitersdk.h"
#include "UMmuSDK.h"
#include "Explorer.h"
#include "OrbiterSoundSDK35.h"

#define MYGRAVSTARTSOUND 1
#define MYGRAVSTOPSOUND  2


HINSTANCE g_hDLL;

//constructor
Explorer::Explorer(OBJHANDLE hObj, int fmodel)
    :VESSEL3(hObj, fmodel)
{
    DefineAnimations();

}

Explorer::~Explorer()
{
}

//Define animation for gravity wheel
void Explorer::DefineAnimations()
{
    static UINT gravwheel_groups[2] = {34, 35};
    static MGROUP_ROTATE gravwheel (0,gravwheel_groups, 2,_V(0,-20,0),_V(0,0,-1),(float)(360*RAD));
    anim_grav = CreateAnimation(0.0);
    AddAnimationComponent (anim_grav, 0, 1, &gravwheel);
}


DLLCLBK void InitModule (HINSTANCE hModule)
{
g_hDLL = hModule;

}

////////////////////////////////////////////////////////
// SendHudMessage - UMMU 2.0
////////////////////////////////////////////////////////
char *Explorer::SendHudMessage()
{
dHudMessageDelay=15;
return cUmmuHudDisplay;
}

//----------------------------------------
//Set vessel class capabilities/capacities
//----------------------------------------
void Explorer::clbkSetClassCaps (FILEHANDLE cfg) 
{ 

	//UMMu Capabilities
	Crew.InitUmmu(GetHandle());// Must always be the first one
	iActiveDockNumber=0;
    iActiveDockNumberForHud = 0;
    SetUMMUAirlockPos();
	// Crew.DefineAirLockShape(TRUE,86,91,-66,-56,1230.2,1240.2);// Airlock open, 6 meter large 8 meter high 14 meter long
	//Crew.SetMembersPosRotOnEVA(_V(88,-66,1235.2),_V(0,0,0));// position when EVA
	Crew.SetMaxSeatAvailableInShip(100);// Max Numbers of UMMU for this ship
	// Add four default members for when the ship is spawned by scenario editor
	Crew.AddCrewMember("Jack Maynard",41,65,74,"Capt");
	Crew.AddCrewMember("Ensign Ogilvie",27,67,55);
	Crew.AddCrewMember("Doctor Hunter",36,70,45,"Doc");
	Crew.AddCrewMember("Lieutenant Patrick",39,70,45);
	iSelectedUmmuMember=0; // Initialize of select member variable
	// The HUD display method variables
	cUmmuHudDisplay[0] =0;// Initialisation of UMmu hud char variable
	dHudMessageDelay =0;// Initialisation of UMmu delay variable
	strcpy(SendHudMessage(),"Welcome aboard! E=EVA   1,2=Previous/Next Crew Member   Shift+1,2=Previous/Next Airlock   S=info   M=add crew   K=Start/Stop Crew Hab Wheel Rotation");

    // The Add Mmu without scenario editor variable see PDF doc
	cAddUMmuToVessel[0]=0;
    THRUSTER_HANDLE th_main, th_rcs[14], th_group[4];

    SetSize (EXP_SIZE);
    SetEmptyMass (EXP_EMPTYMASS);
    SetPMI (EXP_PMI);
    SetCrossSections (EXP_CS);

	// SetDockParams (_V(0,-10,1400.8), _V(0,0,1), _V(0,1,0));

    PROPELLANT_HANDLE ph_main = CreatePropellantResource(EXP_FUELMASS);

    //main engine definition and exhaust locations
    th_main = CreateThruster(_V(0,0,-2268.6), _V(0,0,1), EXP_MAXMAINTH, ph_main, EXP_ISP);
    CreateThrusterGroup(&th_main, 1, THGROUP_MAIN);
    AddExhaust(th_main, 200, 61, _V(-117.6,0,-2268.6), _V(0,0,-1));
    AddExhaust(th_main, 200, 61, _V(117.6,0,-2268.6), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(-82,-138.3,-2212.4), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(82,-138.3,-2212.4), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(82,138.3,-2212.4), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(-82,138.3,-2212.4), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(-255,0,-2213.5), _V(0,0,-1));
    AddExhaust(th_main, 150, 38, _V(255,0,-2213.5), _V(0,0,-1));

    //RCS Engine Definitions
    // **Port-side Aft**
    th_rcs[0] = CreateThruster(_V(-310, 0, -1847.05),_V(1,0,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **Starboard-side Aft**
    th_rcs[1] = CreateThruster(_V(310, 0, -1847.05),_V(-1,0,0), EXP_RCSTH, ph_main, EXP_ISP);
    
    // **Top Aft**
    th_rcs[2] = CreateThruster(_V(-85.28, 190.9, -1374.62), _V(0,-1,0), EXP_RCSTH, ph_main, EXP_ISP);
    th_rcs[3] = CreateThruster(_V(85.28, 190.9, -1374.62), _V(0,-1,0), EXP_RCSTH, ph_main, EXP_ISP);
    
    // **Bottom Aft**
    th_rcs[4] = CreateThruster(_V(-85.28, -190.9, -1374.62), _V(0,1,0), EXP_RCSTH, ph_main, EXP_ISP);
    th_rcs[5] = CreateThruster(_V(85.28, -190.9, -1374.62), _V(0,1,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **Port-side Front**
    th_rcs[6] = CreateThruster(_V(-310,0,1847.05), _V(1,0,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **Starboard-side Front**
    th_rcs[7] = CreateThruster(_V(310.97,0,1847.05), _V(-1,0,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **Bow, Topside**
    th_rcs[8] = CreateThruster(_V(185.28,101.08,1374.62), _V(0,-1,0), EXP_RCSTH, ph_main, EXP_ISP);
    th_rcs[9] = CreateThruster(_V(-185.28,101.08,1374.62), _V(0,-1,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **Bow, Bottom**
    th_rcs[10] = CreateThruster(_V(185.28,-101.08,1374.62), _V(0,1,0), EXP_RCSTH, ph_main, EXP_ISP);
    th_rcs[11] = CreateThruster(_V(-185.28,-101.08,1374.62), _V(0,1,0), EXP_RCSTH, ph_main, EXP_ISP);

    // **forward translation thruster (located on stern of ship)
    th_rcs[12] = CreateThruster(_V(0,0,-2300), _V(0,0,1), EXP_RCSTH, ph_main, EXP_ISP);

    // **reverse translation thruster (located on bow of ship)
    th_rcs[13] = CreateThruster(_V(0,0,2300), _V(0,0,-1), EXP_RCSTH, ph_main, EXP_ISP);

//Define Thruster Groups for Attitude Control

    //**Pitch Up**
    th_group[0] = th_rcs[2];
    th_group[1] = th_rcs[3];
    th_group[2] = th_rcs[10];
    th_group[3] = th_rcs[11];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_PITCHUP);

    //**Pitch Down**
    th_group[0] = th_rcs[4];
    th_group[1] = th_rcs[5];
    th_group[2] = th_rcs[8];
    th_group[3] = th_rcs[9];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_PITCHDOWN);

    //**Bank Left**
    th_group[0] = th_rcs[2];
    th_group[1] = th_rcs[9];
    th_group[2] = th_rcs[10];
    th_group[3] = th_rcs[5];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_BANKLEFT);

    //**Bank Right**
    th_group[0] = th_rcs[3];
    th_group[1] = th_rcs[8];
    th_group[2] = th_rcs[4];
    th_group[3] = th_rcs[11];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_BANKRIGHT);

    //**Attitude Up**
    th_group[0] = th_rcs[4];
    th_group[1] = th_rcs[5];
    th_group[2] = th_rcs[10];
    th_group[3] = th_rcs[11];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_UP);

    //**Attitude Down**
    th_group[0] = th_rcs[2];
    th_group[1] = th_rcs[3];
    th_group[2] = th_rcs[8];
    th_group[3] = th_rcs[9];
    CreateThrusterGroup (th_group, 4, THGROUP_ATT_DOWN);

    //**Yaw Left**
    th_group[0] = th_rcs[7];
    th_group[1] = th_rcs[0];
    CreateThrusterGroup (th_group, 2, THGROUP_ATT_YAWLEFT);

    //**Yaw Right**
    th_group[0] = th_rcs[6];
    th_group[1] = th_rcs[1];
    CreateThrusterGroup (th_group, 2, THGROUP_ATT_YAWRIGHT);

    //**Attitude Left**
    th_group[0] = th_rcs[1];
    th_group[1] = th_rcs[7];
    CreateThrusterGroup (th_group, 2, THGROUP_ATT_LEFT);

    //**Attitude Right**
    th_group[0] = th_rcs[0];
    th_group[1] = th_rcs[6];
    CreateThrusterGroup (th_group, 2, THGROUP_ATT_RIGHT);

    //**Attitude Forward**
    CreateThrusterGroup (th_rcs+12, 1, THGROUP_ATT_FORWARD);

	//**Attitude Reverse**
    CreateThrusterGroup (th_rcs+13, 1, THGROUP_ATT_BACK);

	

	
	//**Docking port marker lights 
	
	//Main Hangar, beginning with Dock 1
	//************************************

			//**Dock 1
			static BEACONLIGHTSPEC docklight1000; 
			static VECTOR3 docklight1000pos = {81,-64, 1230.2};
			static VECTOR3 docklight1000col = {0,1,0};
			docklight1000.shape = BEACONSHAPE_DIFFUSE;
			docklight1000.pos = &docklight1000pos;
			docklight1000.col = &docklight1000col;
			docklight1000.size = 0.5;
			docklight1000.falloff = 0.4;
			docklight1000.period = 0;
			docklight1000.duration = 1;
			docklight1000.tofs = 0;
			docklight1000.active = true; 
			AddBeacon (&docklight1000);

			

			//**Dock 2
			static BEACONLIGHTSPEC docklight2000; 
			static VECTOR3 docklight2000pos = {5,-64, 1230.2};
			static VECTOR3 docklight2000col = {0,1,0};
			docklight2000.shape = BEACONSHAPE_DIFFUSE;
			docklight2000.pos = &docklight2000pos;
			docklight2000.col = &docklight2000col;
			docklight2000.size = 0.5;
			docklight2000.falloff = 0.4;
			docklight2000.period = 0;
			docklight2000.duration = 1;
			docklight2000.tofs = 0;
			docklight2000.active = true; 
			AddBeacon (&docklight2000);

			

			//**Dock 3
			static BEACONLIGHTSPEC docklight3000; 
			static VECTOR3 docklight3000pos = {-71,-64, 1230.2};
			static VECTOR3 docklight3000col = {0,1,0};
			docklight3000.shape = BEACONSHAPE_DIFFUSE;
			docklight3000.pos = &docklight3000pos;
			docklight3000.col = &docklight3000col;
			docklight3000.size = 0.5;
			docklight3000.falloff = 0.4;
			docklight3000.period = 0;
			docklight3000.duration = 1;
			docklight3000.tofs = 0;
			docklight3000.active = true; 
			AddBeacon (&docklight3000);

			

			//**Dock 4
			static BEACONLIGHTSPEC docklight4000; 
			static VECTOR3 docklight4000pos = {81,-64, 1305.2};
			static VECTOR3 docklight4000col = {0,1,0};
			docklight4000.shape = BEACONSHAPE_DIFFUSE;
			docklight4000.pos = &docklight4000pos;
			docklight4000.col = &docklight4000col;
			docklight4000.size = 0.5;
			docklight4000.falloff = 0.4;
			docklight4000.period = 0;
			docklight4000.duration = 1;
			docklight4000.tofs = 0;
			docklight4000.active = true; 
			AddBeacon (&docklight4000);

			

			//**Dock 5
			static BEACONLIGHTSPEC docklight5000; 
			static VECTOR3 docklight5000pos = {5,-64, 1305.2};
			static VECTOR3 docklight5000col = {0,1,0};
			docklight5000.shape = BEACONSHAPE_DIFFUSE;
			docklight5000.pos = &docklight5000pos;
			docklight5000.col = &docklight5000col;
			docklight5000.size = 0.5;
			docklight5000.falloff = 0.4;
			docklight5000.period = 0;
			docklight5000.duration = 1;
			docklight5000.tofs = 0;
			docklight5000.active = true; 
			AddBeacon (&docklight5000);

			

			//**Dock 6
			static BEACONLIGHTSPEC docklight6000; 
			static VECTOR3 docklight6000pos = {-71,-64, 1305.2};
			static VECTOR3 docklight6000col = {0,1,0};
			docklight6000.shape = BEACONSHAPE_DIFFUSE;
			docklight6000.pos = &docklight6000pos;
			docklight6000.col = &docklight6000col;
			docklight6000.size = 0.5;
			docklight6000.falloff = 0.4;
			docklight6000.period = 0;
			docklight6000.duration = 1;
			docklight6000.tofs = 0;
			docklight6000.active = true; 
			AddBeacon (&docklight6000);

			

			//**Dock 7
			static BEACONLIGHTSPEC docklight7000; 
			static VECTOR3 docklight7000pos = {81,-64, 1380.2};
			static VECTOR3 docklight7000col = {0,1,0};
			docklight7000.shape = BEACONSHAPE_DIFFUSE;
			docklight7000.pos = &docklight7000pos;
			docklight7000.col = &docklight7000col;
			docklight7000.size = 0.5;
			docklight7000.falloff = 0.4;
			docklight7000.period = 0;
			docklight7000.duration = 1;
			docklight7000.tofs = 0;
			docklight7000.active = true; 
			AddBeacon (&docklight7000);

			

			//**Dock 8
			static BEACONLIGHTSPEC docklight8000; 
			static VECTOR3 docklight8000pos = {5,-64, 1380.2};
			static VECTOR3 docklight8000col = {0,1,0};
			docklight8000.shape = BEACONSHAPE_DIFFUSE;
			docklight8000.pos = &docklight8000pos;
			docklight8000.col = &docklight8000col;
			docklight8000.size = 0.5;
			docklight8000.falloff = 0.4;
			docklight8000.period = 0;
			docklight8000.duration = 1;
			docklight8000.tofs = 0;
			docklight8000.active = true; 
			AddBeacon (&docklight8000);

			

			//**Dock 9
			static BEACONLIGHTSPEC docklight9000; 
			static VECTOR3 docklight9000pos = {-71,-64, 1380.2};
			static VECTOR3 docklight9000col = {0,1,0};
			docklight9000.shape = BEACONSHAPE_DIFFUSE;
			docklight9000.pos = &docklight9000pos;
			docklight9000.col = &docklight9000col;
			docklight9000.size = 0.5;
			docklight9000.falloff = 0.4;
			docklight9000.period = 0;
			docklight9000.duration = 1;
			docklight9000.tofs = 0;
			docklight9000.active = true; 
			AddBeacon (&docklight9000);

			

			//**Dock 10
			static BEACONLIGHTSPEC docklight10_00; 
			static VECTOR3 docklight10_00pos = {81,-64, 1455.2};
			static VECTOR3 docklight10_00col = {0,1,0};
			docklight10_00.shape = BEACONSHAPE_DIFFUSE;
			docklight10_00.pos = &docklight10_00pos;
			docklight10_00.col = &docklight10_00col;
			docklight10_00.size = 0.5;
			docklight10_00.falloff = 0.4;
			docklight10_00.period = 0;
			docklight10_00.duration = 1;
			docklight10_00.tofs = 0;
			docklight10_00.active = true; 
			AddBeacon (&docklight10_00);

			

			//**Dock 11
			static BEACONLIGHTSPEC docklight1100; 
			static VECTOR3 docklight1100pos = {5,-64, 1455.2};
			static VECTOR3 docklight1100col = {0,1,0};
			docklight1100.shape = BEACONSHAPE_DIFFUSE;
			docklight1100.pos = &docklight1100pos;
			docklight1100.col = &docklight1100col;
			docklight1100.size = 0.5;
			docklight1100.falloff = 0.4;
			docklight1100.period = 0;
			docklight1100.duration = 1;
			docklight1100.tofs = 0;
			docklight1100.active = true; 
			AddBeacon (&docklight1100);

			

			//**Dock 12
			static BEACONLIGHTSPEC docklight1200; 
			static VECTOR3 docklight1200pos = {-71,-64, 1455.2};
			static VECTOR3 docklight1200col = {0,1,0};
			docklight1200.shape = BEACONSHAPE_DIFFUSE;
			docklight1200.pos = &docklight1200pos;
			docklight1200.col = &docklight1200col;
			docklight1200.size = 0.5;
			docklight1200.falloff = 0.4;
			docklight1200.period = 0;
			docklight1200.duration = 1;
			docklight1200.tofs = 0;
			docklight1200.active = true; 
			AddBeacon (&docklight1200);

			
		//Upper Bay - Docks 13-18

			//**Dock 13
			static BEACONLIGHTSPEC docklight1300; 
			static VECTOR3 docklight1300pos = {-65, -114.8, 1597.2};
			static VECTOR3 docklight1300col = {0,0,0.5};
			docklight1300.shape = BEACONSHAPE_DIFFUSE;
			docklight1300.pos = &docklight1300pos;
			docklight1300.col = &docklight1300col;
			docklight1300.size = 0.5;
			docklight1300.falloff = 0.4;
			docklight1300.period = 0;
			docklight1300.duration = 1;
			docklight1300.tofs = 0;
			docklight1300.active = true; 
			AddBeacon (&docklight1300);

			

			//**Dock 14
			static BEACONLIGHTSPEC docklight1400; 
			static VECTOR3 docklight1400pos = {-92, -114.8, 1597.2};
			static VECTOR3 docklight1400col = {0,0,0.5};
			docklight1400.shape = BEACONSHAPE_DIFFUSE;
			docklight1400.pos = &docklight1400pos;
			docklight1400.col = &docklight1400col;
			docklight1400.size = 0.5;
			docklight1400.falloff = 0.4;
			docklight1400.period = 0;
			docklight1400.duration = 1;
			docklight1400.tofs = 0;
			docklight1400.active = true; 
			AddBeacon (&docklight1400);

			

			//**Dock 15
			static BEACONLIGHTSPEC docklight1500; 
			static VECTOR3 docklight1500pos = {-119, -114.8, 1597.2};
			static VECTOR3 docklight1500col = {0,0,0.5};
			docklight1500.shape = BEACONSHAPE_DIFFUSE;
			docklight1500.pos = &docklight1500pos;
			docklight1500.col = &docklight1500col;
			docklight1500.size = 0.5;
			docklight1500.falloff = 0.4;
			docklight1500.period = 0;
			docklight1500.duration = 1;
			docklight1500.tofs = 0;
			docklight1500.active = true; 
			AddBeacon (&docklight1500);

			

			//**Dock 16
			static BEACONLIGHTSPEC docklight1600; 
			static VECTOR3 docklight1600pos = {-65, -114.8, 1697.2};
			static VECTOR3 docklight1600col = {0,0,0.5};
			docklight1600.shape = BEACONSHAPE_DIFFUSE;
			docklight1600.pos = &docklight1600pos;
			docklight1600.col = &docklight1600col;
			docklight1600.size = 0.5;
			docklight1600.falloff = 0.4;
			docklight1600.period = 0;
			docklight1600.duration = 1;
			docklight1600.tofs = 0;
			docklight1600.active = true; 
			AddBeacon (&docklight1600);

			

			//**Dock 17
			static BEACONLIGHTSPEC docklight1700; 
			static VECTOR3 docklight1700pos = {-92, -114.8, 1697.2};
			static VECTOR3 docklight1700col = {0,0,0.5};
			docklight1700.shape = BEACONSHAPE_DIFFUSE;
			docklight1700.pos = &docklight1700pos;
			docklight1700.col = &docklight1700col;
			docklight1700.size = 0.5;
			docklight1700.falloff = 0.4;
			docklight1700.period = 0;
			docklight1700.duration = 1;
			docklight1700.tofs = 0;
			docklight1700.active = true; 
			AddBeacon (&docklight1700);

			

			//**Dock 18
			static BEACONLIGHTSPEC docklight1800; 
			static VECTOR3 docklight1800pos = {-119, -114.8, 1697.2};
			static VECTOR3 docklight1800col = {0,0,0.5};
			docklight1800.shape = BEACONSHAPE_DIFFUSE;
			docklight1800.pos = &docklight1800pos;
			docklight1800.col = &docklight1800col;
			docklight1800.size = 0.5;
			docklight1800.falloff = 0.4;
			docklight1800.period = 0;
			docklight1800.duration = 1;
			docklight1800.tofs = 0;
			docklight1800.active = true; 
			AddBeacon (&docklight1800);

			
		//Lower Bay - Docks 19-24
			//**Dock 19
			static BEACONLIGHTSPEC docklight1900; 
			static VECTOR3 docklight1900pos = {-65, -162.1, 1597.2};
			static VECTOR3 docklight1900col = {0,0,0.5};
			docklight1900.shape = BEACONSHAPE_DIFFUSE;
			docklight1900.pos = &docklight1900pos;
			docklight1900.col = &docklight1900col;
			docklight1900.size = 0.5;
			docklight1900.falloff = 0.4;
			docklight1900.period = 0;
			docklight1900.duration = 1;
			docklight1900.tofs = 0;
			docklight1900.active = true; 
			AddBeacon (&docklight1900);

			//**Dock 20
			static BEACONLIGHTSPEC docklight200; 
			static VECTOR3 docklight200pos = {-92, -162.1, 1597.2};
			static VECTOR3 docklight200col = {0,0,0.5};
			docklight200.shape = BEACONSHAPE_DIFFUSE;
			docklight200.pos = &docklight200pos;
			docklight200.col = &docklight200col;
			docklight200.size = 0.5;
			docklight200.falloff = 0.4;
			docklight200.period = 0;
			docklight200.duration = 1;
			docklight200.tofs = 0;
			docklight200.active = true; 
			AddBeacon (&docklight200);

			//**Dock 21
			static BEACONLIGHTSPEC docklight2100; 
			static VECTOR3 docklight2100pos = {-119, -162.1, 1597.2};
			static VECTOR3 docklight2100col = {0,0,0.5};
			docklight2100.shape = BEACONSHAPE_DIFFUSE;
			docklight2100.pos = &docklight2100pos;
			docklight2100.col = &docklight2100col;
			docklight2100.size = 0.5;
			docklight2100.falloff = 0.4;
			docklight2100.period = 0;
			docklight2100.duration = 1;
			docklight2100.tofs = 0;
			docklight2100.active = true; 
			AddBeacon (&docklight2100);

			//**Dock 22
			static BEACONLIGHTSPEC docklight2200; 
			static VECTOR3 docklight2200pos = {-65, -162.1, 1697.2};
			static VECTOR3 docklight2200col = {0,0,0.5};
			docklight2200.shape = BEACONSHAPE_DIFFUSE;
			docklight2200.pos = &docklight2200pos;
			docklight2200.col = &docklight2200col;
			docklight2200.size = 0.5;
			docklight2200.falloff = 0.4;
			docklight2200.period = 0;
			docklight2200.duration = 1;
			docklight2200.tofs = 0;
			docklight2200.active = true; 
			AddBeacon (&docklight2200);

			//**Dock 23
			static BEACONLIGHTSPEC docklight2300; 
			static VECTOR3 docklight2300pos = {-92, -162.1, 1697.2};
			static VECTOR3 docklight2300col = {0,0,0.5};
			docklight2300.shape = BEACONSHAPE_DIFFUSE;
			docklight2300.pos = &docklight2300pos;
			docklight2300.col = &docklight2300col;
			docklight2300.size = 0.5;
			docklight2300.falloff = 0.4;
			docklight2300.period = 0;
			docklight2300.duration = 1;
			docklight2300.tofs = 0;
			docklight2300.active = true; 
			AddBeacon (&docklight2300);

			//**Dock 24
			static BEACONLIGHTSPEC docklight2400; 
			static VECTOR3 docklight2400pos = {-119, -162.1, 1697.2};
			static VECTOR3 docklight2400col = {0,0,0.5};
			docklight2400.shape = BEACONSHAPE_DIFFUSE;
			docklight2400.pos = &docklight2400pos;
			docklight2400.col = &docklight2400col;
			docklight2400.size = 0.5;
			docklight2400.falloff = 0.4;
			docklight2400.period = 0;
			docklight2400.duration = 1;
			docklight2400.tofs = 0;
			docklight2400.active = true; 
			AddBeacon (&docklight2400); 

			

	
	//Landing Approach Lights
        
        //**Main Hangar - Row 1
        static BEACONLIGHTSPEC apprlight1000;
        static VECTOR3 apprlight1000pos = {81, -66, 1480.2};
        static VECTOR3 apprlight1000col = {1,1,1};
        apprlight1000.shape = BEACONSHAPE_STAR;
        apprlight1000.pos = &apprlight1000pos;
        apprlight1000.col = &apprlight1000col;
        apprlight1000.size = 0.4;
        apprlight1000.falloff = 0.4;
        apprlight1000.period = 2;
        apprlight1000.duration = 0.1;
        apprlight1000.tofs = 0.1;
        apprlight1000.active = true;
        AddBeacon (&apprlight1000); 

        static BEACONLIGHTSPEC apprlight1001;
        static VECTOR3 apprlight1001pos = {81, -66, 1500.2};
        static VECTOR3 apprlight1001col = {1,1,1};
        apprlight1001.shape = BEACONSHAPE_STAR;
        apprlight1001.pos = &apprlight1001pos;
        apprlight1001.col = &apprlight1001col;
        apprlight1001.size = 0.4;
        apprlight1001.falloff = 0.4;
        apprlight1001.period = 2;
        apprlight1001.duration = 0.1;
        apprlight1001.tofs = 0.2;
        apprlight1001.active = true;
        AddBeacon (&apprlight1001);

        static BEACONLIGHTSPEC apprlight1002;
        static VECTOR3 apprlight1002pos = {81, -66, 1520.2};
        static VECTOR3 apprlight1002col = {1,1,1};
        apprlight1002.shape = BEACONSHAPE_STAR;
        apprlight1002.pos = &apprlight1002pos;
        apprlight1002.col = &apprlight1002col;
        apprlight1002.size = 0.4;
        apprlight1002.falloff = 0.4;
        apprlight1002.period = 2;
        apprlight1002.duration = 0.1;
        apprlight1002.tofs = 0.3;
        apprlight1002.active = true;
        AddBeacon (&apprlight1002);

        static BEACONLIGHTSPEC apprlight1003;
        static VECTOR3 apprlight1003pos = {81, -66, 1540.2};
        static VECTOR3 apprlight1003col = {1,1,1};
        apprlight1003.shape = BEACONSHAPE_STAR;
        apprlight1003.pos = &apprlight1003pos;
        apprlight1003.col = &apprlight1003col;
        apprlight1003.size = 0.4;
        apprlight1003.falloff = 0.4;
        apprlight1003.period = 2;
        apprlight1003.duration = 0.1;
        apprlight1003.tofs = 0.4;
        apprlight1003.active = true;
        AddBeacon (&apprlight1003);

        static BEACONLIGHTSPEC apprlight1004;
        static VECTOR3 apprlight1004pos = {81, -66, 1560.2};
        static VECTOR3 apprlight1004col = {1,1,1};
        apprlight1004.shape = BEACONSHAPE_STAR;
        apprlight1004.pos = &apprlight1004pos;
        apprlight1004.col = &apprlight1004col;
        apprlight1004.size = 0.4;
        apprlight1004.falloff = 0.4;
        apprlight1004.period = 2;
        apprlight1004.duration = 0.1;
        apprlight1004.tofs = 0.5;
        apprlight1004.active = true;
        AddBeacon (&apprlight1004);

        static BEACONLIGHTSPEC apprlight1005;
        static VECTOR3 apprlight1005pos = {81, -66, 1580.2};
        static VECTOR3 apprlight1005col = {1,1,1};
        apprlight1005.shape = BEACONSHAPE_STAR;
        apprlight1005.pos = &apprlight1005pos;
        apprlight1005.col = &apprlight1005col;
        apprlight1005.size = 0.4;
        apprlight1005.falloff = 0.4;
        apprlight1005.period = 2;
        apprlight1005.duration = 0.1;
        apprlight1005.tofs = 0.6;
        apprlight1005.active = true;
        AddBeacon (&apprlight1005);

        static BEACONLIGHTSPEC apprlight1006;
        static VECTOR3 apprlight1006pos = {81, -66, 1600.2};
        static VECTOR3 apprlight1006col = {1,1,1};
        apprlight1006.shape = BEACONSHAPE_STAR;
        apprlight1006.pos = &apprlight1006pos;
        apprlight1006.col = &apprlight1006col;
        apprlight1006.size = 0.4;
        apprlight1006.falloff = 0.4;
        apprlight1006.period = 2;
        apprlight1006.duration = 0.1;
        apprlight1006.tofs = 0.7;
        apprlight1006.active = true;
        AddBeacon (&apprlight1006);

        static BEACONLIGHTSPEC apprlight1007;
        static VECTOR3 apprlight1007pos = {81, -66, 1620.2};
        static VECTOR3 apprlight1007col = {1,1,1};
        apprlight1007.shape = BEACONSHAPE_STAR;
        apprlight1007.pos = &apprlight1007pos;
        apprlight1007.col = &apprlight1007col;
        apprlight1007.size = 0.4;
        apprlight1007.falloff = 0.4;
        apprlight1007.period = 2;
        apprlight1007.duration = 0.1;
        apprlight1007.tofs = 0.8;
        apprlight1007.active = true;
        AddBeacon (&apprlight1007);

        static BEACONLIGHTSPEC apprlight1008;
        static VECTOR3 apprlight1008pos = {81, -66, 1640.2};
        static VECTOR3 apprlight1008col = {1,1,1};
        apprlight1008.shape = BEACONSHAPE_STAR;
        apprlight1008.pos = &apprlight1008pos;
        apprlight1008.col = &apprlight1008col;
        apprlight1008.size = 0.4;
        apprlight1008.falloff = 0.4;
        apprlight1008.period = 2;
        apprlight1008.duration = 0.1;
        apprlight1008.tofs = 0.9;
        apprlight1008.active = true;
        AddBeacon (&apprlight1008);

        static BEACONLIGHTSPEC apprlight1009;
        static VECTOR3 apprlight1009pos = {81, -66, 1660.2};
        static VECTOR3 apprlight1009col = {1,1,1};
        apprlight1009.shape = BEACONSHAPE_STAR;
        apprlight1009.pos = &apprlight1009pos;
        apprlight1009.col = &apprlight1009col;
        apprlight1009.size = 0.4;
        apprlight1009.falloff = 0.4;
        apprlight1009.period = 2;
        apprlight1009.duration = 0.1;
        apprlight1009.tofs = 1.0;
        apprlight1009.active = true;
        AddBeacon (&apprlight1009);

        static BEACONLIGHTSPEC apprlight1010;
        static VECTOR3 apprlight1010pos = {81, -66, 1680.2};
        static VECTOR3 apprlight1010col = {1,1,1};
        apprlight1010.shape = BEACONSHAPE_STAR;
        apprlight1010.pos = &apprlight1010pos;
        apprlight1010.col = &apprlight1010col;
        apprlight1010.size = 0.4;
        apprlight1010.falloff = 0.4;
        apprlight1010.period = 2;
        apprlight1010.duration = 0.1;
        apprlight1010.tofs = 1.1;
        apprlight1010.active = true;
        AddBeacon (&apprlight1010);

        
        static BEACONLIGHTSPEC apprlight1011;
        static VECTOR3 apprlight1011pos = {81, -66, 1700.2};
        static VECTOR3 apprlight1011col = {1,1,1};
        apprlight1011.shape = BEACONSHAPE_STAR;
        apprlight1011.pos = &apprlight1011pos;
        apprlight1011.col = &apprlight1011col;
        apprlight1011.size = 0.4;
        apprlight1011.falloff = 0.4;
        apprlight1011.period = 2;
        apprlight1011.duration = 0.1;
        apprlight1011.tofs = 1.2;
        apprlight1011.active = true;
        AddBeacon (&apprlight1011);

        static BEACONLIGHTSPEC apprlight1012;
        static VECTOR3 apprlight1012pos = {81, -66, 1720.2};
        static VECTOR3 apprlight1012col = {1,1,1};
        apprlight1012.shape = BEACONSHAPE_STAR;
        apprlight1012.pos = &apprlight1012pos;
        apprlight1012.col = &apprlight1012col;
        apprlight1012.size = 0.4;
        apprlight1012.falloff = 0.4;
        apprlight1012.period = 2;
        apprlight1012.duration = 0.1;
        apprlight1012.tofs = 1.3;
        apprlight1012.active = true;
        AddBeacon (&apprlight1012);

        static BEACONLIGHTSPEC apprlight1013;
        static VECTOR3 apprlight1013pos = {81, -66, 1740.2};
        static VECTOR3 apprlight1013col = {1,1,1};
        apprlight1013.shape = BEACONSHAPE_STAR;
        apprlight1013.pos = &apprlight1013pos;
        apprlight1013.col = &apprlight1013col;
        apprlight1013.size = 0.4;
        apprlight1013.falloff = 0.4;
        apprlight1013.period = 2;
        apprlight1013.duration = 0.1;
        apprlight1013.tofs = 1.4;
        apprlight1013.active = true;
        AddBeacon (&apprlight1013);

        static BEACONLIGHTSPEC apprlight1014;
        static VECTOR3 apprlight1014pos = {81, -66, 1760.2};
        static VECTOR3 apprlight1014col = {1,1,1};
        apprlight1014.shape = BEACONSHAPE_STAR;
        apprlight1014.pos = &apprlight1014pos;
        apprlight1014.col = &apprlight1014col;
        apprlight1014.size = 0.4;
        apprlight1014.falloff = 0.4;
        apprlight1014.period = 2;
        apprlight1014.duration = 0.1;
        apprlight1014.tofs = 1.5;
        apprlight1014.active = true;
        AddBeacon (&apprlight1014);

        static BEACONLIGHTSPEC apprlight1015;
        static VECTOR3 apprlight1015pos = {81, -66, 1780.2};
        static VECTOR3 apprlight1015col = {1,1,1};
        apprlight1015.shape = BEACONSHAPE_STAR;
        apprlight1015.pos = &apprlight1015pos;
        apprlight1015.col = &apprlight1015col;
        apprlight1015.size = 0.4;
        apprlight1015.falloff = 0.4;
        apprlight1015.period = 2;
        apprlight1015.duration = 0.1;
        apprlight1015.tofs = 1.6;
        apprlight1015.active = true;
        AddBeacon (&apprlight1015);

        static BEACONLIGHTSPEC apprlight1016;
        static VECTOR3 apprlight1016pos = {81, -66, 1800.2};
        static VECTOR3 apprlight1016col = {1,1,1};
        apprlight1016.shape = BEACONSHAPE_STAR;
        apprlight1016.pos = &apprlight1016pos;
        apprlight1016.col = &apprlight1016col;
        apprlight1016.size = 0.4;
        apprlight1016.falloff = 0.4;
        apprlight1016.period = 2;
        apprlight1016.duration = 0.1;
        apprlight1016.tofs = 1.7;
        apprlight1016.active = true;
        AddBeacon (&apprlight1016);

        static BEACONLIGHTSPEC apprlight1017;
        static VECTOR3 apprlight1017pos = {81, -66, 1820.2};
        static VECTOR3 apprlight1017col = {1,1,1};
        apprlight1017.shape = BEACONSHAPE_STAR;
        apprlight1017.pos = &apprlight1017pos;
        apprlight1017.col = &apprlight1017col;
        apprlight1017.size = 0.4;
        apprlight1017.falloff = 0.4;
        apprlight1017.period = 2;
        apprlight1017.duration = 0.1;
        apprlight1017.tofs = 1.8;
        apprlight1017.active = true;
        AddBeacon (&apprlight1017);

		//**Main Hangar - Row 2
        static BEACONLIGHTSPEC apprlight2000;
        static VECTOR3 apprlight2000pos = {5, -66, 1480.2};
        static VECTOR3 apprlight2000col = {1,1,1};
        apprlight2000.shape = BEACONSHAPE_STAR;
        apprlight2000.pos = &apprlight2000pos;
        apprlight2000.col = &apprlight2000col;
        apprlight2000.size = 0.4;
        apprlight2000.falloff = 0.4;
        apprlight2000.period = 2;
        apprlight2000.duration = 0.1;
        apprlight2000.tofs = 0.1;
        apprlight2000.active = true;
        AddBeacon (&apprlight2000);

        static BEACONLIGHTSPEC apprlight2001;
        static VECTOR3 apprlight2001pos = {5, -66, 1500.2};
        static VECTOR3 apprlight2001col = {1,1,1};
        apprlight2001.shape = BEACONSHAPE_STAR;
        apprlight2001.pos = &apprlight2001pos;
        apprlight2001.col = &apprlight2001col;
        apprlight2001.size = 0.4;
        apprlight2001.falloff = 0.4;
        apprlight2001.period = 2;
        apprlight2001.duration = 0.1;
        apprlight2001.tofs = 0.2;
        apprlight2001.active = true;
        AddBeacon(&apprlight2001);

        static BEACONLIGHTSPEC apprlight2002;
        static VECTOR3 apprlight2002pos = {5, -66, 1520.2};
        static VECTOR3 apprlight2002col = {1,1,1};
        apprlight2002.shape = BEACONSHAPE_STAR;
        apprlight2002.pos = &apprlight2002pos;
        apprlight2002.col = &apprlight2002col;
        apprlight2002.size = 0.4;
        apprlight2002.falloff = 0.4;
        apprlight2002.period = 2;
        apprlight2002.duration = 0.1;
        apprlight2002.tofs = 0.3;
        apprlight2002.active = true;
        AddBeacon (&apprlight2002);

        static BEACONLIGHTSPEC apprlight2003;
        static VECTOR3 apprlight2003pos = {5, -66, 1540.2};
        static VECTOR3 apprlight2003col = {1,1,1};
        apprlight2003.shape = BEACONSHAPE_STAR;
        apprlight2003.pos = &apprlight2003pos;
        apprlight2003.col = &apprlight2003col;
        apprlight2003.size = 0.4;
        apprlight2003.falloff = 0.4;
        apprlight2003.period = 2;
        apprlight2003.duration = 0.1;
        apprlight2003.tofs = 0.4;
        apprlight2003.active = true;
        AddBeacon (&apprlight2003);

        static BEACONLIGHTSPEC apprlight2004;
        static VECTOR3 apprlight2004pos = {5, -66, 1560.2};
        static VECTOR3 apprlight2004col = {1,1,1};
        apprlight2004.shape = BEACONSHAPE_STAR;
        apprlight2004.pos = &apprlight2004pos;
        apprlight2004.col = &apprlight2004col;
        apprlight2004.size = 0.4;
        apprlight2004.falloff = 0.4;
        apprlight2004.period = 2;
        apprlight2004.duration = 0.1;
        apprlight2004.tofs = 0.5;
        apprlight2004.active = true;
        AddBeacon (&apprlight2004);

        static BEACONLIGHTSPEC apprlight2005;
        static VECTOR3 apprlight2005pos = {5, -66, 1580.2};
        static VECTOR3 apprlight2005col = {1,1,1};
        apprlight2005.shape = BEACONSHAPE_STAR;
        apprlight2005.pos = &apprlight2005pos;
        apprlight2005.col = &apprlight2005col;
        apprlight2005.size = 0.4;
        apprlight2005.falloff = 0.4;
        apprlight2005.period = 2;
        apprlight2005.duration = 0.1;
        apprlight2005.tofs = 0.6;
        apprlight2005.active = true;
        AddBeacon (&apprlight2005);

        static BEACONLIGHTSPEC apprlight2006;
        static VECTOR3 apprlight2006pos = {5, -66, 1600.2};
        static VECTOR3 apprlight2006col = {1,1,1};
        apprlight2006.shape = BEACONSHAPE_STAR;
        apprlight2006.pos = &apprlight2006pos;
        apprlight2006.col = &apprlight2006col;
        apprlight2006.size = 0.4;
        apprlight2006.falloff = 0.4;
        apprlight2006.period = 2;
        apprlight2006.duration = 0.1;
        apprlight2006.tofs = 0.7;
        apprlight2006.active = true;
        AddBeacon (&apprlight2006);

        static BEACONLIGHTSPEC apprlight2007;
        static VECTOR3 apprlight2007pos = {5, -66, 1620.2};
        static VECTOR3 apprlight2007col = {1,1,1};
        apprlight2007.shape = BEACONSHAPE_STAR;
        apprlight2007.pos = &apprlight2007pos;
        apprlight2007.col = &apprlight2007col;
        apprlight2007.size = 0.4;
        apprlight2007.falloff = 0.4;
        apprlight2007.period = 2;
        apprlight2007.duration = 0.1;
        apprlight2007.tofs = 0.8;
        apprlight2007.active = true;
        AddBeacon (&apprlight2007);

        static BEACONLIGHTSPEC apprlight2008;
        static VECTOR3 apprlight2008pos = {5, -66, 1640.2};
        static VECTOR3 apprlight2008col = {1,1,1};
        apprlight2008.shape = BEACONSHAPE_STAR;
        apprlight2008.pos = &apprlight2008pos;
        apprlight2008.col = &apprlight2008col;
        apprlight2008.size = 0.4;
        apprlight2008.falloff = 0.4;
        apprlight2008.period = 2;
        apprlight2008.duration = 0.1;
        apprlight2008.tofs = 0.9;
        apprlight2008.active = true;
        AddBeacon (&apprlight2008);

        static BEACONLIGHTSPEC apprlight2009;
        static VECTOR3 apprlight2009pos = {5, -66, 1660.2};
        static VECTOR3 apprlight2009col = {1,1,1};
        apprlight2009.shape = BEACONSHAPE_STAR;
        apprlight2009.pos = &apprlight2009pos;
        apprlight2009.col = &apprlight2009col;
        apprlight2009.size = 0.4;
        apprlight2009.falloff = 0.4;
        apprlight2009.period = 2;
        apprlight2009.duration = 0.1;
        apprlight2009.tofs = 1.0;
        apprlight2009.active = true;
        AddBeacon (&apprlight2009);

        static BEACONLIGHTSPEC apprlight2010;
        static VECTOR3 apprlight2010pos = {5, -66, 1680.2};
        static VECTOR3 apprlight2010col = {1,1,1};
        apprlight2010.shape = BEACONSHAPE_STAR;
        apprlight2010.pos = &apprlight2010pos;
        apprlight2010.col = &apprlight2010col;
        apprlight2010.size = 0.4;
        apprlight2010.falloff = 0.4;
        apprlight2010.period = 2;
        apprlight2010.duration = 0.1;
        apprlight2010.tofs = 1.1;
        apprlight2010.active = true;
        AddBeacon (&apprlight2010);

        
        static BEACONLIGHTSPEC apprlight2011;
        static VECTOR3 apprlight2011pos = {5, -66, 1700.2};
        static VECTOR3 apprlight2011col = {1,1,1};
        apprlight2011.shape = BEACONSHAPE_STAR;
        apprlight2011.pos = &apprlight2011pos;
        apprlight2011.col = &apprlight2011col;
        apprlight2011.size = 0.4;
        apprlight2011.falloff = 0.4;
        apprlight2011.period = 2;
        apprlight2011.duration = 0.1;
        apprlight2011.tofs = 1.2;
        apprlight2011.active = true;
        AddBeacon (&apprlight2011);

        static BEACONLIGHTSPEC apprlight2012;
        static VECTOR3 apprlight2012pos = {5, -66, 1720.2};
        static VECTOR3 apprlight2012col = {1,1,1};
        apprlight2012.shape = BEACONSHAPE_STAR;
        apprlight2012.pos = &apprlight2012pos;
        apprlight2012.col = &apprlight2012col;
        apprlight2012.size = 0.4;
        apprlight2012.falloff = 0.4;
        apprlight2012.period = 2;
        apprlight2012.duration = 0.1;
        apprlight2012.tofs = 1.3;
        apprlight2012.active = true;
        AddBeacon (&apprlight2012);

        static BEACONLIGHTSPEC apprlight2013;
        static VECTOR3 apprlight2013pos = {5, -66, 1740.2};
        static VECTOR3 apprlight2013col = {1,1,1};
        apprlight2013.shape = BEACONSHAPE_STAR;
        apprlight2013.pos = &apprlight2013pos;
        apprlight2013.col = &apprlight2013col;
        apprlight2013.size = 0.4;
        apprlight2013.falloff = 0.4;
        apprlight2013.period = 2;
        apprlight2013.duration = 0.1;
        apprlight2013.tofs = 1.4;
        apprlight2013.active = true;
        AddBeacon (&apprlight2013);

        static BEACONLIGHTSPEC apprlight2014;
        static VECTOR3 apprlight2014pos = {5, -66, 1760.2};
        static VECTOR3 apprlight2014col = {1,1,1};
        apprlight2014.shape = BEACONSHAPE_STAR;
        apprlight2014.pos = &apprlight2014pos;
        apprlight2014.col = &apprlight2014col;
        apprlight2014.size = 0.4;
        apprlight2014.falloff = 0.4;
        apprlight2014.period = 2;
        apprlight2014.duration = 0.1;
        apprlight2014.tofs = 1.5;
        apprlight2014.active = true;
        AddBeacon (&apprlight2014);

        static BEACONLIGHTSPEC apprlight2015;
        static VECTOR3 apprlight2015pos = {5, -66, 1780.2};
        static VECTOR3 apprlight2015col = {1,1,1};
        apprlight2015.shape = BEACONSHAPE_STAR;
        apprlight2015.pos = &apprlight2015pos;
        apprlight2015.col = &apprlight2015col;
        apprlight2015.size = 0.4;
        apprlight2015.falloff = 0.4;
        apprlight2015.period = 2;
        apprlight2015.duration = 0.1;
        apprlight2015.tofs = 1.6;
        apprlight2015.active = true;
        AddBeacon (&apprlight2015);

        static BEACONLIGHTSPEC apprlight2016;
        static VECTOR3 apprlight2016pos = {5, -66, 1800.2};
        static VECTOR3 apprlight2016col = {1,1,1};
        apprlight2016.shape = BEACONSHAPE_STAR;
        apprlight2016.pos = &apprlight2016pos;
        apprlight2016.col = &apprlight2016col;
        apprlight2016.size = 0.4;
        apprlight2016.falloff = 0.4;
        apprlight2016.period = 2;
        apprlight2016.duration = 0.1;
        apprlight2016.tofs = 1.7;
        apprlight2016.active = true;
        AddBeacon (&apprlight2016);

        static BEACONLIGHTSPEC apprlight2017;
        static VECTOR3 apprlight2017pos = {5, -66, 1820.2};
        static VECTOR3 apprlight2017col = {1,1,1};
        apprlight2017.shape = BEACONSHAPE_STAR;
        apprlight2017.pos = &apprlight2017pos;
        apprlight2017.col = &apprlight2017col;
        apprlight2017.size = 0.4;
        apprlight2017.falloff = 0.4;
        apprlight2017.period = 2;
        apprlight2017.duration = 0.1;
        apprlight2017.tofs = 1.8;
        apprlight2017.active = true;
        AddBeacon (&apprlight2017);

		//**Main Hangar - Row 3
        static BEACONLIGHTSPEC apprlight3000;
        static VECTOR3 apprlight3000pos = {-71, -66, 1480.2};
        static VECTOR3 apprlight3000col = {1,1,1};
        apprlight3000.shape = BEACONSHAPE_STAR;
        apprlight3000.pos = &apprlight3000pos;
        apprlight3000.col = &apprlight3000col;
        apprlight3000.size = 0.4;
        apprlight3000.falloff = 0.4;
        apprlight3000.period = 2;
        apprlight3000.duration = 0.1;
        apprlight3000.tofs = 0.1;
        apprlight3000.active = true;
        AddBeacon (&apprlight3000); 

        static BEACONLIGHTSPEC apprlight3001;
        static VECTOR3 apprlight3001pos = {-71, -66, 1500.2};
        static VECTOR3 apprlight3001col = {1,1,1};
        apprlight3001.shape = BEACONSHAPE_STAR;
        apprlight3001.pos = &apprlight3001pos;
        apprlight3001.col = &apprlight3001col;
        apprlight3001.size = 0.4;
        apprlight3001.falloff = 0.4;
        apprlight3001.period = 2;
        apprlight3001.duration = 0.1;
        apprlight3001.tofs = 0.2;
        apprlight3001.active = true;
        AddBeacon(&apprlight3001);

        static BEACONLIGHTSPEC apprlight3002;
        static VECTOR3 apprlight3002pos = {-71, -66, 1520.2};
        static VECTOR3 apprlight3002col = {1,1,1};
        apprlight3002.shape = BEACONSHAPE_STAR;
        apprlight3002.pos = &apprlight3002pos;
        apprlight3002.col = &apprlight3002col;
        apprlight3002.size = 0.4;
        apprlight3002.falloff = 0.4;
        apprlight3002.period = 2;
        apprlight3002.duration = 0.1;
        apprlight3002.tofs = 0.3;
        apprlight3002.active = true;
        AddBeacon (&apprlight3002);

        static BEACONLIGHTSPEC apprlight3003;
        static VECTOR3 apprlight3003pos = {-71, -66, 1540.2};
        static VECTOR3 apprlight3003col = {1,1,1};
        apprlight3003.shape = BEACONSHAPE_STAR;
        apprlight3003.pos = &apprlight3003pos;
        apprlight3003.col = &apprlight3003col;
        apprlight3003.size = 0.4;
        apprlight3003.falloff = 0.4;
        apprlight3003.period = 2;
        apprlight3003.duration = 0.1;
        apprlight3003.tofs = 0.4;
        apprlight3003.active = true;
        AddBeacon (&apprlight3003);

        static BEACONLIGHTSPEC apprlight3004;
        static VECTOR3 apprlight3004pos = {-71, -66, 1560.2};
        static VECTOR3 apprlight3004col = {1,1,1};
        apprlight3004.shape = BEACONSHAPE_STAR;
        apprlight3004.pos = &apprlight3004pos;
        apprlight3004.col = &apprlight3004col;
        apprlight3004.size = 0.4;
        apprlight3004.falloff = 0.4;
        apprlight3004.period = 2;
        apprlight3004.duration = 0.1;
        apprlight3004.tofs = 0.5;
        apprlight3004.active = true;
        AddBeacon (&apprlight3004);

        static BEACONLIGHTSPEC apprlight3005;
        static VECTOR3 apprlight3005pos = {-71, -66, 1580.2};
        static VECTOR3 apprlight3005col = {1,1,1};
        apprlight3005.shape = BEACONSHAPE_STAR;
        apprlight3005.pos = &apprlight3005pos;
        apprlight3005.col = &apprlight3005col;
        apprlight3005.size = 0.4;
        apprlight3005.falloff = 0.4;
        apprlight3005.period = 2;
        apprlight3005.duration = 0.1;
        apprlight3005.tofs = 0.6;
        apprlight3005.active = true;
        AddBeacon (&apprlight3005);

        static BEACONLIGHTSPEC apprlight3006;
        static VECTOR3 apprlight3006pos = {-71, -66, 1600.2};
        static VECTOR3 apprlight3006col = {1,1,1};
        apprlight3006.shape = BEACONSHAPE_STAR;
        apprlight3006.pos = &apprlight3006pos;
        apprlight3006.col = &apprlight3006col;
        apprlight3006.size = 0.4;
        apprlight3006.falloff = 0.4;
        apprlight3006.period = 2;
        apprlight3006.duration = 0.1;
        apprlight3006.tofs = 0.7;
        apprlight3006.active = true;
        AddBeacon (&apprlight3006);

        static BEACONLIGHTSPEC apprlight3007;
        static VECTOR3 apprlight3007pos = {-71, -66, 1620.2};
        static VECTOR3 apprlight3007col = {1,1,1};
        apprlight3007.shape = BEACONSHAPE_STAR;
        apprlight3007.pos = &apprlight3007pos;
        apprlight3007.col = &apprlight3007col;
        apprlight3007.size = 0.4;
        apprlight3007.falloff = 0.4;
        apprlight3007.period = 2;
        apprlight3007.duration = 0.1;
        apprlight3007.tofs = 0.8;
        apprlight3007.active = true;
        AddBeacon (&apprlight3007);

        static BEACONLIGHTSPEC apprlight3008;
        static VECTOR3 apprlight3008pos = {-71, -66, 1640.2};
        static VECTOR3 apprlight3008col = {1,1,1};
        apprlight3008.shape = BEACONSHAPE_STAR;
        apprlight3008.pos = &apprlight3008pos;
        apprlight3008.col = &apprlight3008col;
        apprlight3008.size = 0.4;
        apprlight3008.falloff = 0.4;
        apprlight3008.period = 2;
        apprlight3008.duration = 0.1;
        apprlight3008.tofs = 0.9;
        apprlight3008.active = true;
        AddBeacon (&apprlight3008);

        static BEACONLIGHTSPEC apprlight3009;
        static VECTOR3 apprlight3009pos = {-71, -66, 1660.2};
        static VECTOR3 apprlight3009col = {1,1,1};
        apprlight3009.shape = BEACONSHAPE_STAR;
        apprlight3009.pos = &apprlight3009pos;
        apprlight3009.col = &apprlight3009col;
        apprlight3009.size = 0.4;
        apprlight3009.falloff = 0.4;
        apprlight3009.period = 2;
        apprlight3009.duration = 0.1;
        apprlight3009.tofs = 1.0;
        apprlight3009.active = true;
        AddBeacon (&apprlight3009);

        static BEACONLIGHTSPEC apprlight3010;
        static VECTOR3 apprlight3010pos = {-71, -66, 1680.2};
        static VECTOR3 apprlight3010col = {1,1,1};
        apprlight3010.shape = BEACONSHAPE_STAR;
        apprlight3010.pos = &apprlight3010pos;
        apprlight3010.col = &apprlight3010col;
        apprlight3010.size = 0.4;
        apprlight3010.falloff = 0.4;
        apprlight3010.period = 2;
        apprlight3010.duration = 0.1;
        apprlight3010.tofs = 1.1;
        apprlight3010.active = true;
        AddBeacon (&apprlight3010);

        
        static BEACONLIGHTSPEC apprlight3011;
        static VECTOR3 apprlight3011pos = {-71, -66, 1700.2};
        static VECTOR3 apprlight3011col = {1,1,1};
        apprlight3011.shape = BEACONSHAPE_STAR;
        apprlight3011.pos = &apprlight3011pos;
        apprlight3011.col = &apprlight3011col;
        apprlight3011.size = 0.4;
        apprlight3011.falloff = 0.4;
        apprlight3011.period = 2;
        apprlight3011.duration = 0.1;
        apprlight3011.tofs = 1.2;
        apprlight3011.active = true;
        AddBeacon (&apprlight3011);

        static BEACONLIGHTSPEC apprlight3012;
        static VECTOR3 apprlight3012pos = {-71, -66, 1720.2};
        static VECTOR3 apprlight3012col = {1,1,1};
        apprlight3012.shape = BEACONSHAPE_STAR;
        apprlight3012.pos = &apprlight3012pos;
        apprlight3012.col = &apprlight3012col;
        apprlight3012.size = 0.4;
        apprlight3012.falloff = 0.4;
        apprlight3012.period = 2;
        apprlight3012.duration = 0.1;
        apprlight3012.tofs = 1.3;
        apprlight3012.active = true;
        AddBeacon (&apprlight3012);

        static BEACONLIGHTSPEC apprlight3013;
        static VECTOR3 apprlight3013pos = {-71, -66, 1740.2};
        static VECTOR3 apprlight3013col = {1,1,1};
        apprlight3013.shape = BEACONSHAPE_STAR;
        apprlight3013.pos = &apprlight3013pos;
        apprlight3013.col = &apprlight3013col;
        apprlight3013.size = 0.4;
        apprlight3013.falloff = 0.4;
        apprlight3013.period = 2;
        apprlight3013.duration = 0.1;
        apprlight3013.tofs = 1.4;
        apprlight3013.active = true;
        AddBeacon (&apprlight3013);

        static BEACONLIGHTSPEC apprlight3014;
        static VECTOR3 apprlight3014pos = {-71, -66, 1760.2};
        static VECTOR3 apprlight3014col = {1,1,1};
        apprlight3014.shape = BEACONSHAPE_STAR;
        apprlight3014.pos = &apprlight3014pos;
        apprlight3014.col = &apprlight3014col;
        apprlight3014.size = 0.4;
        apprlight3014.falloff = 0.4;
        apprlight3014.period = 2;
        apprlight3014.duration = 0.1;
        apprlight3014.tofs = 1.5;
        apprlight3014.active = true;
        AddBeacon (&apprlight3014);

        static BEACONLIGHTSPEC apprlight3015;
        static VECTOR3 apprlight3015pos = {-71, -66, 1780.2};
        static VECTOR3 apprlight3015col = {1,1,1};
        apprlight3015.shape = BEACONSHAPE_STAR;
        apprlight3015.pos = &apprlight3015pos;
        apprlight3015.col = &apprlight3015col;
        apprlight3015.size = 0.4;
        apprlight3015.falloff = 0.4;
        apprlight3015.period = 2;
        apprlight3015.duration = 0.1;
        apprlight3015.tofs = 1.6;
        apprlight3015.active = true;
        AddBeacon (&apprlight3015);

        static BEACONLIGHTSPEC apprlight3016;
        static VECTOR3 apprlight3016pos = {-71, -66, 1800.2};
        static VECTOR3 apprlight3016col = {1,1,1};
        apprlight3016.shape = BEACONSHAPE_STAR;
        apprlight3016.pos = &apprlight3016pos;
        apprlight3016.col = &apprlight3016col;
        apprlight3016.size = 0.4;
        apprlight3016.falloff = 0.4;
        apprlight3016.period = 2;
        apprlight3016.duration = 0.1;
        apprlight3016.tofs = 1.7;
        apprlight3016.active = true;
        AddBeacon (&apprlight3016);

        static BEACONLIGHTSPEC apprlight3017;
        static VECTOR3 apprlight3017pos = {-71, -66, 1820.2};
        static VECTOR3 apprlight3017col = {1,1,1};
        apprlight3017.shape = BEACONSHAPE_STAR;
        apprlight3017.pos = &apprlight3017pos;
        apprlight3017.col = &apprlight3017col;
        apprlight3017.size = 0.4;
        apprlight3017.falloff = 0.4;
        apprlight3017.period = 2;
        apprlight3017.duration = 0.1;
        apprlight3017.tofs = 1.8;
        apprlight3017.active = true;
        AddBeacon (&apprlight3017);

	//**Upper Bay Row 1
			static BEACONLIGHTSPEC apprlight401;
			static VECTOR3 apprlight401pos = {-65, -116.8, 1767.2};
			static VECTOR3 apprlight401col = {1,1,1};
			apprlight401.shape = BEACONSHAPE_STAR;
			apprlight401.pos = &apprlight401pos; 
			apprlight401.col = &apprlight401col;
			apprlight401.size = 0.3;
			apprlight401.falloff = 0.4;
			apprlight401.period = 1.0;
			apprlight401.duration = 0.16;
			apprlight401.tofs = 0.16;
			apprlight401.active = true;
			AddBeacon (&apprlight401);

			static BEACONLIGHTSPEC apprlight402;
			static VECTOR3 apprlight402pos = {-65,-116.8, 1787.2};
			static VECTOR3 apprlight402col = {1,1,1};
			apprlight402.shape = BEACONSHAPE_STAR;
			apprlight402.pos = &apprlight402pos; 
			apprlight402.col = &apprlight402col;
			apprlight402.size = 0.3;
			apprlight402.falloff = 0.4;
			apprlight402.period = 1.0;
			apprlight402.duration = 0.16;
			apprlight402.tofs = 0.32;
			apprlight402.active = true;
			AddBeacon (&apprlight402);

			static BEACONLIGHTSPEC apprlight403;
			static VECTOR3 apprlight403pos = {-65, -116.8, 1807.2};
			static VECTOR3 apprlight403col = {1,1,1};
			apprlight403.shape = BEACONSHAPE_STAR;
			apprlight403.pos = &apprlight403pos; 
			apprlight403.col = &apprlight403col;
			apprlight403.size = 0.3;
			apprlight403.falloff = 0.4;
			apprlight403.period = 1.0;
			apprlight403.duration = 0.16;
			apprlight403.tofs = 0.48;
			apprlight403.active = true;
			AddBeacon (&apprlight403);

			static BEACONLIGHTSPEC apprlight404;
			static VECTOR3 apprlight404pos = {-65, -116.8, 1827.2};
			static VECTOR3 apprlight404col = {1,1,1};
			apprlight404.shape = BEACONSHAPE_STAR;
			apprlight404.pos = &apprlight404pos; 
			apprlight404.col = &apprlight404col;
			apprlight404.size = 0.3;
			apprlight404.falloff = 0.3;
			apprlight404.period = 1.0;
			apprlight404.duration = 0.16;
			apprlight404.tofs = 0.64;
			apprlight404.active = true;
			AddBeacon (&apprlight404);

			static BEACONLIGHTSPEC apprlight405;
			static VECTOR3 apprlight405pos = {-65, -116.8, 1847.2};
			static VECTOR3 apprlight405col = {1,1,1};
			apprlight405.shape = BEACONSHAPE_STAR;
			apprlight405.pos = &apprlight405pos; 
			apprlight405.col = &apprlight405col;
			apprlight405.size = 0.3;
			apprlight405.falloff = 0.4;
			apprlight405.period = 1.0;
			apprlight405.duration = 0.16;
			apprlight405.tofs = 0.8;
			apprlight405.active = true;
			AddBeacon (&apprlight405);

			static BEACONLIGHTSPEC apprlight406;
			static VECTOR3 apprlight406pos = {-65, -116.8, 1867.2};
			static VECTOR3 apprlight406col = {1,1,1};
			apprlight406.shape = BEACONSHAPE_STAR;
			apprlight406.pos = &apprlight406pos; 
			apprlight406.col = &apprlight406col;
			apprlight406.size = 0.3;
			apprlight406.falloff = 0.4;
			apprlight406.period = 1.0;
			apprlight406.duration = 0.16;
			apprlight406.tofs = 0.96;
			apprlight406.active = true;
			AddBeacon (&apprlight406);

			static BEACONLIGHTSPEC apprlight407;
			static VECTOR3 apprlight407pos = {-65, -116.8, 1887.2};
			static VECTOR3 apprlight407col = {1,1,1};
			apprlight407.shape = BEACONSHAPE_STAR;
			apprlight407.pos = &apprlight407pos; 
			apprlight407.col = &apprlight407col;
			apprlight407.size = 0.3;
			apprlight407.falloff = 0.4;
			apprlight407.period = 1.0;
			apprlight407.duration = 0.16;
			apprlight407.tofs = 1.12;
			apprlight407.active = true;
			AddBeacon (&apprlight407);

			static BEACONLIGHTSPEC apprlight408;
			static VECTOR3 apprlight408pos = {-65, -116.8, 1907.2};
			static VECTOR3 apprlight408col = {1,1,1};
			apprlight408.shape = BEACONSHAPE_STAR;
			apprlight408.pos = &apprlight408pos; 
			apprlight408.col = &apprlight408col;
			apprlight408.size = 0.3;
			apprlight408.falloff = 0.4;
			apprlight408.period = 1.0;
			apprlight408.duration = 0.16;
			apprlight408.tofs = 1.28;
			apprlight408.active = true;
			AddBeacon (&apprlight408);

			static BEACONLIGHTSPEC apprlight409;
			static VECTOR3 apprlight409pos = {-65, -116.8, 1927.2};
			static VECTOR3 apprlight409col = {1,1,1};
			apprlight409.shape = BEACONSHAPE_STAR;
			apprlight409.pos = &apprlight409pos; 
			apprlight409.col = &apprlight409col;
			apprlight409.size = 0.3;
			apprlight409.falloff = 0.4;
			apprlight409.period = 1.0;
			apprlight409.duration = 0.16;
			apprlight409.tofs = 1.44;
			apprlight409.active = true;
			AddBeacon (&apprlight409);

    //**Upper Bay Row 2
			static BEACONLIGHTSPEC apprlight500;
			static VECTOR3 apprlight500pos = {-92, -116.8, 1747.2};
			static VECTOR3 apprlight500col = {1,1,1};
			apprlight500.shape = BEACONSHAPE_STAR;
			apprlight500.pos = &apprlight500pos; 
			apprlight500.col = &apprlight500col;
			apprlight500.size = 0.3;
			apprlight500.falloff = 0.4;
			apprlight500.period = 1.0;
			apprlight500.duration = 0.16;
			apprlight500.tofs = 0.16;
			apprlight500.active = true;
			AddBeacon (&apprlight500);

			static BEACONLIGHTSPEC apprlight501;
			static VECTOR3 apprlight501pos = {-92, -116.8, 1767.2};
			static VECTOR3 apprlight501col = {1,1,1};
			apprlight501.shape = BEACONSHAPE_STAR;
			apprlight501.pos = &apprlight501pos; 
			apprlight501.col = &apprlight501col;
			apprlight501.size = 0.3;
			apprlight501.falloff = 0.4;
			apprlight501.period = 1.0;
			apprlight501.duration = 0.16;
			apprlight501.tofs = 0.32;
			apprlight501.active = true;
			AddBeacon (&apprlight501);

			static BEACONLIGHTSPEC apprlight502;
			static VECTOR3 apprlight502pos = {-92, -116.8, 1787.2};
			static VECTOR3 apprlight502col = {1,1,1};
			apprlight502.shape = BEACONSHAPE_STAR;
			apprlight502.pos = &apprlight502pos; 
			apprlight502.col = &apprlight502col;
			apprlight502.size = 0.3;
			apprlight502.falloff = 0.4;
			apprlight502.period = 1.0;
			apprlight502.duration = 0.16;
			apprlight502.tofs = 0.48;
			apprlight502.active = true;
			AddBeacon (&apprlight502);

			static BEACONLIGHTSPEC apprlight503;
			static VECTOR3 apprlight503pos = {-92, -116.8, 1807.2};
			static VECTOR3 apprlight503col = {1,1,1};
			apprlight503.shape = BEACONSHAPE_STAR;
			apprlight503.pos = &apprlight503pos; 
			apprlight503.col = &apprlight503col;
			apprlight503.size = 0.3;
			apprlight503.falloff = 0.4;
			apprlight503.period = 1.0;
			apprlight503.duration = 0.16;
			apprlight503.tofs = 0.64;
			apprlight503.active = true;
			AddBeacon (&apprlight503);

			static BEACONLIGHTSPEC apprlight504;
			static VECTOR3 apprlight504pos = {-92, -116.8, 1827.2};
			static VECTOR3 apprlight504col = {1,1,1};
			apprlight504.shape = BEACONSHAPE_STAR;
			apprlight504.pos = &apprlight504pos; 
			apprlight504.col = &apprlight504col;
			apprlight504.size = 0.3;
			apprlight504.falloff = 0.4;
			apprlight504.period = 1.0;
			apprlight504.duration = 0.16;
			apprlight504.tofs = 0.80;
			apprlight504.active = true;
			AddBeacon (&apprlight504);

			static BEACONLIGHTSPEC apprlight505;
			static VECTOR3 apprlight505pos = {-92, -116.8, 1847.2};
			static VECTOR3 apprlight505col = {1,1,1};
			apprlight505.shape = BEACONSHAPE_STAR;
			apprlight505.pos = &apprlight505pos; 
			apprlight505.col = &apprlight505col;
			apprlight505.size = 0.3;
			apprlight505.falloff = 0.4;
			apprlight505.period = 1.0;
			apprlight505.duration = 0.16;
			apprlight505.tofs = 0.96;
			apprlight505.active = true;
			AddBeacon (&apprlight505);

			static BEACONLIGHTSPEC apprlight506;
			static VECTOR3 apprlight506pos = {-92, -116.8, 1867.2};
			static VECTOR3 apprlight506col = {1,1,1};
			apprlight506.shape = BEACONSHAPE_STAR;
			apprlight506.pos = &apprlight506pos; 
			apprlight506.col = &apprlight506col;
			apprlight506.size = 0.3;
			apprlight506.falloff = 0.4;
			apprlight506.period = 1.0;
			apprlight506.duration = 0.16;
			apprlight506.tofs = 1.12;
			apprlight506.active = true;
			AddBeacon (&apprlight506);

			static BEACONLIGHTSPEC apprlight507;
			static VECTOR3 apprlight507pos = {-92, -116.8, 1887.2};
			static VECTOR3 apprlight507col = {1,1,1};
			apprlight507.shape = BEACONSHAPE_STAR;
			apprlight507.pos = &apprlight507pos; 
			apprlight507.col = &apprlight507col;
			apprlight507.size = 0.3;
			apprlight507.falloff = 0.4;
			apprlight507.period = 1.0;
			apprlight507.duration = 0.16;
			apprlight507.tofs = 1.28;
			apprlight507.active = true;
			AddBeacon (&apprlight507);

			static BEACONLIGHTSPEC apprlight508;
			static VECTOR3 apprlight508pos = {-92, -116.8, 1907.2};
			static VECTOR3 apprlight508col = {1,1,1};
			apprlight508.shape = BEACONSHAPE_STAR;
			apprlight508.pos = &apprlight508pos; 
			apprlight508.col = &apprlight508col;
			apprlight508.size = 0.3;
			apprlight508.falloff = 0.4;
			apprlight508.period = 1.0;
			apprlight508.duration = 0.16;
			apprlight508.tofs = 1.44;
			apprlight508.active = true;
			AddBeacon (&apprlight508);

			

  //**Upper Bay Row 3
			static BEACONLIGHTSPEC apprlight601;
			static VECTOR3 apprlight601pos = {-119, -116.8, 1767.2};
			static VECTOR3 apprlight601col = {1,1,1};
			apprlight601.shape = BEACONSHAPE_STAR;
			apprlight601.pos = &apprlight601pos; 
			apprlight601.col = &apprlight601col;
			apprlight601.size = 0.3;
			apprlight601.falloff = 0.4;
			apprlight601.period = 1.0;
			apprlight601.duration = 0.16;
			apprlight601.tofs = 0.16;
			apprlight601.active = true;
			AddBeacon (&apprlight601);

			static BEACONLIGHTSPEC apprlight602;
			static VECTOR3 apprlight602pos = {-119, -116.8, 1787.2};
			static VECTOR3 apprlight602col = {1,1,1};
			apprlight602.shape = BEACONSHAPE_STAR;
			apprlight602.pos = &apprlight602pos; 
			apprlight602.col = &apprlight602col;
			apprlight602.size = 0.3;
			apprlight602.falloff = 0.4;
			apprlight602.period = 1.0;
			apprlight602.duration = 0.16;
			apprlight602.tofs = 0.32;
			apprlight602.active = true;
			AddBeacon (&apprlight602);

			static BEACONLIGHTSPEC apprlight603;
			static VECTOR3 apprlight603pos = {-119, -116.8, 1807.2};
			static VECTOR3 apprlight603col = {1,1,1};
			apprlight603.shape = BEACONSHAPE_STAR;
			apprlight603.pos = &apprlight603pos; 
			apprlight603.col = &apprlight603col;
			apprlight603.size = 0.3;
		    apprlight603.falloff = 0.4;
			apprlight603.period = 1.0;
			apprlight603.duration = 0.16;
			apprlight603.tofs = 0.48;
			apprlight603.active = true;
			AddBeacon (&apprlight603);

			static BEACONLIGHTSPEC apprlight604;
			static VECTOR3 apprlight604pos = {-119, -116.8, 1827.2};
			static VECTOR3 apprlight604col = {1,1,1};
			apprlight604.shape = BEACONSHAPE_STAR;
			apprlight604.pos = &apprlight604pos; 
			apprlight604.col = &apprlight604col;
			apprlight604.size = 0.3;
			apprlight604.falloff = 0.4;
			apprlight604.period = 1.0;
			apprlight604.duration = 0.16;
			apprlight604.tofs = 0.64;
			apprlight604.active = true;
			AddBeacon (&apprlight604);

			static BEACONLIGHTSPEC apprlight605;
			static VECTOR3 apprlight605pos = {-119, -116.8, 1847.2};
			static VECTOR3 apprlight605col = {1,1,1};
			apprlight605.shape = BEACONSHAPE_STAR;
			apprlight605.pos = &apprlight605pos; 
			apprlight605.col = &apprlight605col;
			apprlight605.size = 0.3;
			apprlight605.falloff = 0.4;
			apprlight605.period = 1.0;
			apprlight605.duration = 0.16;
			apprlight605.tofs = 0.80;
			apprlight605.active = true;
			AddBeacon (&apprlight605);

			static BEACONLIGHTSPEC apprlight606;
			static VECTOR3 apprlight606pos = {-119, -116.8, 1867.2};
			static VECTOR3 apprlight606col = {1,1,1};
			apprlight606.shape = BEACONSHAPE_STAR;
			apprlight606.pos = &apprlight606pos; 
			apprlight606.col = &apprlight606col;
			apprlight606.size = 0.3;
			apprlight606.falloff = 0.4;
			apprlight606.period = 1.0;
			apprlight606.duration = 0.16;
			apprlight606.tofs = 0.96;
			apprlight606.active = true;
			AddBeacon (&apprlight606);

			static BEACONLIGHTSPEC apprlight607;
			static VECTOR3 apprlight607pos = {-119, -116.8, 1887.2};
			static VECTOR3 apprlight607col = {1,1,1};
			apprlight607.shape = BEACONSHAPE_STAR;
			apprlight607.pos = &apprlight607pos; 
			apprlight607.col = &apprlight607col;
			apprlight607.size = 0.3;
			apprlight607.falloff = 0.4;
			apprlight607.period = 1.0;
			apprlight607.duration = 0.16;
			apprlight607.tofs = 1.12;
			apprlight607.active = true;
			AddBeacon (&apprlight607);

			static BEACONLIGHTSPEC apprlight608;
			static VECTOR3 apprlight608pos = {-119, -116.8, 1907.2};
			static VECTOR3 apprlight608col = {1,1,1};
			apprlight608.shape = BEACONSHAPE_STAR;
			apprlight608.pos = &apprlight608pos; 
			apprlight608.col = &apprlight608col;
			apprlight608.size = 0.3;
			apprlight608.falloff = 0.4;
			apprlight608.period = 1.0;
			apprlight608.duration = 0.16;
			apprlight608.tofs = 1.28;
			apprlight608.active = true;
			AddBeacon (&apprlight608);

			static BEACONLIGHTSPEC apprlight609;
			static VECTOR3 apprlight609pos = {-119, -116.8, 1927.2};
			static VECTOR3 apprlight609col = {1,1,1};
			apprlight609.shape = BEACONSHAPE_STAR;
			apprlight609.pos = &apprlight609pos; 
			apprlight609.col = &apprlight609col;
			apprlight609.size = 0.3;
			apprlight609.falloff = 0.4;
			apprlight609.period = 1.0;
			apprlight609.duration = 0.16;
			apprlight609.tofs = 1.44;
			apprlight609.active = true;
			AddBeacon (&apprlight609);

	//**Lower Bay Row 1
			static BEACONLIGHTSPEC apprlight701;
			static VECTOR3 apprlight701pos = {-65, -164.1, 1767.2};
			static VECTOR3 apprlight701col = {1,1,1};
			apprlight701.shape = BEACONSHAPE_STAR;
			apprlight701.pos = &apprlight701pos; 
			apprlight701.col = &apprlight701col;
			apprlight701.size = 0.3;
			apprlight701.falloff = 0.4;
			apprlight701.period = 1.0;
			apprlight701.duration = 0.16;
			apprlight701.tofs = 0.16;
			apprlight701.active = true;
			AddBeacon (&apprlight701);

			static BEACONLIGHTSPEC apprlight702;
			static VECTOR3 apprlight702pos = {-65, -164.1, 1787.2};
			static VECTOR3 apprlight702col = {1,1,1};
			apprlight702.shape = BEACONSHAPE_STAR;
			apprlight702.pos = &apprlight702pos; 
			apprlight702.col = &apprlight702col;
			apprlight702.size = 0.3;
			apprlight702.falloff = 0.4;
			apprlight702.period = 1.0;
			apprlight702.duration = 0.16;
			apprlight702.tofs = 0.32;
			apprlight702.active = true;
			AddBeacon (&apprlight702);

			static BEACONLIGHTSPEC apprlight703;
			static VECTOR3 apprlight703pos = {-65, -164.1, 1807.2};
			static VECTOR3 apprlight703col = {1,1,1};
			apprlight703.shape = BEACONSHAPE_STAR;
			apprlight703.pos = &apprlight703pos; 
			apprlight703.col = &apprlight703col;
			apprlight703.size = 0.3;
			apprlight703.falloff = 0.4;
			apprlight703.period = 1.0;
			apprlight703.duration = 0.16;
			apprlight703.tofs = 0.48;
			apprlight703.active = true;
			AddBeacon (&apprlight703);

			static BEACONLIGHTSPEC apprlight704;
			static VECTOR3 apprlight704pos = {-65, -164.1, 1827.2};
			static VECTOR3 apprlight704col = {1,1,1};
			apprlight704.shape = BEACONSHAPE_STAR;
			apprlight704.pos = &apprlight704pos; 
			apprlight704.col = &apprlight704col;
			apprlight704.size = 0.3;
			apprlight704.falloff = 0.3;
			apprlight704.period = 1.0;
			apprlight704.duration = 0.16;
			apprlight704.tofs = 0.64;
			apprlight704.active = true;
			AddBeacon (&apprlight704);

			static BEACONLIGHTSPEC apprlight705;
			static VECTOR3 apprlight705pos = {-65, -164.1, 1847.2};
			static VECTOR3 apprlight705col = {1,1,1};
			apprlight705.shape = BEACONSHAPE_STAR;
			apprlight705.pos = &apprlight705pos; 
			apprlight705.col = &apprlight705col;
			apprlight705.size = 0.3;
			apprlight705.falloff = 0.4;
			apprlight705.period = 1.0;
			apprlight705.duration = 0.16;
			apprlight705.tofs = 0.80;
			apprlight705.active = true;
			AddBeacon (&apprlight705);

			static BEACONLIGHTSPEC apprlight706;
			static VECTOR3 apprlight706pos = {-65, -164.1, 1867.2};
			static VECTOR3 apprlight706col = {1,1,1};
			apprlight706.shape = BEACONSHAPE_STAR;
			apprlight706.pos = &apprlight706pos; 
			apprlight706.col = &apprlight706col;
			apprlight706.size = 0.3;
			apprlight706.falloff = 0.4;
			apprlight706.period = 1.0;
			apprlight706.duration = 0.16;
			apprlight706.tofs = 0.96;
			apprlight706.active = true;
			AddBeacon (&apprlight706);

			static BEACONLIGHTSPEC apprlight707;
			static VECTOR3 apprlight707pos = {-65, -164.1, 1887.2};
			static VECTOR3 apprlight707col = {1,1,1};
			apprlight707.shape = BEACONSHAPE_STAR;
			apprlight707.pos = &apprlight707pos; 
			apprlight707.col = &apprlight707col;
			apprlight707.size = 0.3;
			apprlight707.falloff = 0.4;
			apprlight707.period = 1.0;
			apprlight707.duration = 0.16;
			apprlight707.tofs = 1.12;
			apprlight707.active = true;
			AddBeacon (&apprlight707);

			static BEACONLIGHTSPEC apprlight708;
			static VECTOR3 apprlight708pos = {-65, -164.1, 1907.2};
			static VECTOR3 apprlight708col = {1,1,1};
			apprlight708.shape = BEACONSHAPE_STAR;
			apprlight708.pos = &apprlight708pos; 
			apprlight708.col = &apprlight708col;
			apprlight708.size = 0.3;
			apprlight708.falloff = 0.4;
			apprlight708.period = 1.0;
			apprlight708.duration = 0.16;
			apprlight708.tofs = 1.28;
			apprlight708.active = true;
			AddBeacon (&apprlight708);

			static BEACONLIGHTSPEC apprlight709;
			static VECTOR3 apprlight709pos = {-65, -164.1, 1927.2};
			static VECTOR3 apprlight709col = {1,1,1};
			apprlight709.shape = BEACONSHAPE_STAR;
			apprlight709.pos = &apprlight709pos; 
			apprlight709.col = &apprlight709col;
			apprlight709.size = 0.3;
			apprlight709.falloff = 0.4;
			apprlight709.period = 1.0;
			apprlight709.duration = 0.16;
			apprlight709.tofs = 1.44;
			apprlight709.active = true;
			AddBeacon (&apprlight709);

		//**Lower Bay Row 2
			static BEACONLIGHTSPEC apprlight800;
			static VECTOR3 apprlight800pos = {-92, -164.1, 1747.2};
			static VECTOR3 apprlight800col = {1,1,1};
			apprlight800.shape = BEACONSHAPE_STAR;
			apprlight800.pos = &apprlight800pos; 
			apprlight800.col = &apprlight800col;
			apprlight800.size = 0.3;
			apprlight800.falloff = 0.4;
			apprlight800.period = 1.0;
			apprlight800.duration = 0.16;
			apprlight800.tofs = 0.16;
			apprlight800.active = true;
			AddBeacon (&apprlight800);

			static BEACONLIGHTSPEC apprlight801;
			static VECTOR3 apprlight801pos = {-92, -164.1, 1767.2};
			static VECTOR3 apprlight801col = {1,1,1};
			apprlight801.shape = BEACONSHAPE_STAR;
			apprlight801.pos = &apprlight801pos; 
			apprlight801.col = &apprlight801col;
			apprlight801.size = 0.3;
			apprlight801.falloff = 0.4;
			apprlight801.period = 1.0;
			apprlight801.duration = 0.16;
			apprlight801.tofs = 0.32;
			apprlight801.active = true;
			AddBeacon (&apprlight801);

			static BEACONLIGHTSPEC apprlight802;
			static VECTOR3 apprlight802pos = {-92, -164.1, 1787.2};
			static VECTOR3 apprlight802col = {1,1,1};
			apprlight802.shape = BEACONSHAPE_STAR;
			apprlight802.pos = &apprlight802pos; 
			apprlight802.col = &apprlight802col;
			apprlight802.size = 0.3;
			apprlight802.falloff = 0.4;
			apprlight802.period = 1.0;
			apprlight802.duration = 0.16;
			apprlight802.tofs = 0.48;
			apprlight802.active = true;
			AddBeacon (&apprlight802);

			static BEACONLIGHTSPEC apprlight803;
			static VECTOR3 apprlight803pos = {-92, -164.1, 1807.2};
			static VECTOR3 apprlight803col = {1,1,1};
			apprlight803.shape = BEACONSHAPE_STAR;
			apprlight803.pos = &apprlight803pos; 
			apprlight803.col = &apprlight803col;
			apprlight803.size = 0.3;
			apprlight803.falloff = 0.4;
			apprlight803.period = 1.0;
			apprlight803.duration = 0.16;
			apprlight803.tofs = 0.64;
			apprlight803.active = true;
			AddBeacon (&apprlight803);

			static BEACONLIGHTSPEC apprlight804;
			static VECTOR3 apprlight804pos = {-92, -164.1, 1827.2};
			static VECTOR3 apprlight804col = {1,1,1};
			apprlight804.shape = BEACONSHAPE_STAR;
			apprlight804.pos = &apprlight804pos; 
			apprlight804.col = &apprlight804col;
			apprlight804.size = 0.3;
			apprlight804.falloff = 0.4;
			apprlight804.period = 1.0;
			apprlight804.duration = 0.16;
			apprlight804.tofs = 0.80;
			apprlight804.active = true;
			AddBeacon (&apprlight804);

			static BEACONLIGHTSPEC apprlight805;
			static VECTOR3 apprlight805pos = {-92, -164.1, 1847.2};
			static VECTOR3 apprlight805col = {1,1,1};
			apprlight805.shape = BEACONSHAPE_STAR;
			apprlight805.pos = &apprlight805pos; 
			apprlight805.col = &apprlight805col;
			apprlight805.size = 0.3;
			apprlight805.falloff = 0.4;
			apprlight805.period = 1.0;
			apprlight805.duration = 0.16;
			apprlight805.tofs = 0.96;
			apprlight805.active = true;
			AddBeacon (&apprlight805);

			static BEACONLIGHTSPEC apprlight806;
			static VECTOR3 apprlight806pos = {-92, -164.1, 1867.2};
			static VECTOR3 apprlight806col = {1,1,1};
			apprlight806.shape = BEACONSHAPE_STAR;
			apprlight806.pos = &apprlight806pos; 
			apprlight806.col = &apprlight806col;
			apprlight806.size = 0.3;
			apprlight806.falloff = 0.4;
			apprlight806.period = 1.0;
			apprlight806.duration = 0.16;
			apprlight806.tofs = 1.12;
			apprlight806.active = true;
			AddBeacon (&apprlight806);

			static BEACONLIGHTSPEC apprlight807;
			static VECTOR3 apprlight807pos = {-92, -164.1, 1887.2};
			static VECTOR3 apprlight807col = {1,1,1};
			apprlight807.shape = BEACONSHAPE_STAR;
			apprlight807.pos = &apprlight807pos; 
			apprlight807.col = &apprlight807col;
			apprlight807.size = 0.3;
			apprlight807.falloff = 0.4;
			apprlight807.period = 1.0;
			apprlight807.duration = 0.16;
			apprlight807.tofs = 1.28;
			apprlight807.active = true;
			AddBeacon (&apprlight807);

			static BEACONLIGHTSPEC apprlight808;
			static VECTOR3 apprlight808pos = {-92, -164.1, 1907.2};
			static VECTOR3 apprlight808col = {1,1,1};
			apprlight808.shape = BEACONSHAPE_STAR;
			apprlight808.pos = &apprlight808pos; 
			apprlight808.col = &apprlight808col;
			apprlight808.size = 0.3;
			apprlight808.falloff = 0.4;
			apprlight808.period = 1.0;
			apprlight808.duration = 0.16;
			apprlight808.tofs = 1.44;
			apprlight808.active = true;
			AddBeacon (&apprlight808);


		//**Lower Bay Row 3
			static BEACONLIGHTSPEC apprlight901;
			static VECTOR3 apprlight901pos = {-119, -164.1, 1767.2};
			static VECTOR3 apprlight901col = {1,1,1};
			apprlight901.shape = BEACONSHAPE_STAR;
			apprlight901.pos = &apprlight901pos; 
			apprlight901.col = &apprlight901col;
			apprlight901.size = 0.3;
			apprlight901.falloff = 0.4;
			apprlight901.period = 1.0;
			apprlight901.duration = 0.16;
			apprlight901.tofs = 0.16;
			apprlight901.active = true;
			AddBeacon (&apprlight901);

			static BEACONLIGHTSPEC apprlight902;
			static VECTOR3 apprlight902pos = {-119, -164.1, 1787.2};
			static VECTOR3 apprlight902col = {1,1,1};
			apprlight902.shape = BEACONSHAPE_STAR;
			apprlight902.pos = &apprlight902pos; 
			apprlight902.col = &apprlight902col;
			apprlight902.size = 0.3;
			apprlight902.falloff = 0.4;
			apprlight902.period = 1.0;
			apprlight902.duration = 0.16;
			apprlight902.tofs = 0.32;
			apprlight902.active = true;
			AddBeacon (&apprlight902);

			static BEACONLIGHTSPEC apprlight903;
			static VECTOR3 apprlight903pos = {-119, -164.1, 1807.2};
			static VECTOR3 apprlight903col = {1,1,1};
			apprlight903.shape = BEACONSHAPE_STAR;
			apprlight903.pos = &apprlight903pos; 
			apprlight903.col = &apprlight903col;
			apprlight903.size = 0.3;
			apprlight903.falloff = 0.4;
			apprlight903.period = 1.0;
			apprlight903.duration = 0.16;
			apprlight903.tofs = 0.48;
			apprlight903.active = true;
			AddBeacon (&apprlight903);

			static BEACONLIGHTSPEC apprlight904;
			static VECTOR3 apprlight904pos = {-119, -164.1, 1827.2};
			static VECTOR3 apprlight904col = {1,1,1};
			apprlight904.shape = BEACONSHAPE_STAR;
			apprlight904.pos = &apprlight904pos; 
			apprlight904.col = &apprlight904col;
			apprlight904.size = 0.3;
			apprlight904.falloff = 0.4;
			apprlight904.period = 1.0;
			apprlight904.duration = 0.16;
			apprlight904.tofs = 0.64;
			apprlight904.active = true;
			AddBeacon (&apprlight904);

			static BEACONLIGHTSPEC apprlight905;
			static VECTOR3 apprlight905pos = {-119, -164.1, 1847.2};
			static VECTOR3 apprlight905col = {1,1,1};
			apprlight905.shape = BEACONSHAPE_STAR;
			apprlight905.pos = &apprlight905pos; 
			apprlight905.col = &apprlight905col;
			apprlight905.size = 0.3;
			apprlight905.falloff = 0.4;
			apprlight905.period = 1.0;
			apprlight905.duration = 0.16;
			apprlight905.tofs = 0.80;
			apprlight905.active = true;
			AddBeacon (&apprlight905);

			static BEACONLIGHTSPEC apprlight906;
			static VECTOR3 apprlight906pos = {-119, -164.1, 1867.2};
			static VECTOR3 apprlight906col = {1,1,1};
			apprlight906.shape = BEACONSHAPE_STAR;
			apprlight906.pos = &apprlight906pos; 
			apprlight906.col = &apprlight906col;
			apprlight906.size = 0.3;
			apprlight906.falloff = 0.4;
			apprlight906.period = 1.0;
			apprlight906.duration = 0.16;
			apprlight906.tofs = 0.96;
			apprlight906.active = true;
			AddBeacon (&apprlight906);

			static BEACONLIGHTSPEC apprlight907;
			static VECTOR3 apprlight907pos = {-119, -164.1, 1887.2};
			static VECTOR3 apprlight907col = {1,1,1};
			apprlight907.shape = BEACONSHAPE_STAR;
			apprlight907.pos = &apprlight907pos; 
			apprlight907.col = &apprlight907col;
			apprlight907.size = 0.3;
			apprlight907.falloff = 0.4;
			apprlight907.period = 1.0;
			apprlight907.duration = 0.16;
			apprlight907.tofs = 1.12;
			apprlight907.active = true;
			AddBeacon (&apprlight907);

			static BEACONLIGHTSPEC apprlight908;
			static VECTOR3 apprlight908pos = {-119, -164.1, 1907.2};
			static VECTOR3 apprlight908col = {1,1,1};
			apprlight908.shape = BEACONSHAPE_STAR;
			apprlight908.pos = &apprlight908pos; 
			apprlight908.col = &apprlight908col;
			apprlight908.size = 0.3;
			apprlight908.falloff = 0.4;
			apprlight908.period = 1.0;
			apprlight908.duration = 0.16;
			apprlight908.tofs = 1.28;
			apprlight908.active = true;
			AddBeacon (&apprlight908);

			static BEACONLIGHTSPEC apprlight909;
			static VECTOR3 apprlight909pos = {-119, -164.1, 1927.2};
			static VECTOR3 apprlight909col = {1,1,1};
			apprlight909.shape = BEACONSHAPE_STAR;
			apprlight909.pos = &apprlight909pos; 
			apprlight909.col = &apprlight909col;
			apprlight909.size = 0.3;
			apprlight909.falloff = 0.4;
			apprlight909.period = 1.0;
			apprlight909.duration = 0.16;
			apprlight909.tofs = 1.44;
			apprlight909.active = true;
			AddBeacon (&apprlight909);



	//**Camera Offset**
    SetCameraOffset (_V(0,101.08,1874.62));

    //**Add the mesh**
    AddMesh("Explorer"); 


}

void Explorer::SetUMMUAirlockPos(void)
{
		int AirlockStatus=Crew.GetAirlockDoorState();
		Crew.SetActiveDockForTransfer(iActiveDockNumber);

		switch(iActiveDockNumber)
		{

		case 0:
			Crew.DefineAirLockShape(AirLockStatus,79,83,-66,-62,1228,1232);
			Crew.SetMembersPosRotOnEVA(_V(81,-64,1231),_V(0,0,0));
			break;

		case 1:
			Crew.DefineAirLockShape(AirLockStatus,3,7,-66,-62,1228,1232);
			Crew.SetMembersPosRotOnEVA(_V(5,-64,1231),_V(0,0,0));
			break;

		case 2:
			Crew.DefineAirLockShape(AirLockStatus,-73,-69,-66,-62,1228,1232);
			Crew.SetMembersPosRotOnEVA(_V(-71,-64,1231),_V(0,0,0));
			break;

		case 3:
			Crew.DefineAirLockShape(AirLockStatus,79,83,-66,-62,1303,1307);
			Crew.SetMembersPosRotOnEVA(_V(81,-64,1306),_V(0,0,0));
			break;

		case 4:
			Crew.DefineAirLockShape(AirLockStatus,3,7,-66,-62,1303,1307);
			Crew.SetMembersPosRotOnEVA(_V(5,-64,1306),_V(0,0,0));
			break;

		case 5:
			Crew.DefineAirLockShape(AirLockStatus,-73,-69,-66,-62,1303,1307);
			Crew.SetMembersPosRotOnEVA(_V(-71,-64,1306),_V(0,0,0));
			break;

		case 6:
			Crew.DefineAirLockShape(AirLockStatus,79,83,-66,-62,1378,1382);
			Crew.SetMembersPosRotOnEVA(_V(81,-64,1381),_V(0,0,0));
			break;

		case 7:
			Crew.DefineAirLockShape(AirLockStatus,3,7,-66,-62,1378,1382);
			Crew.SetMembersPosRotOnEVA(_V(5,-64,1381),_V(0,0,0));
			break;

		case 8:
			Crew.DefineAirLockShape(AirLockStatus,-73,-69,-66,-62,1378,1382);
			Crew.SetMembersPosRotOnEVA(_V(-71,-64,1381),_V(0,0,0));
			break;

		case 9:
			Crew.DefineAirLockShape(AirLockStatus,79,83,-66,-62,1453,1457);
			Crew.SetMembersPosRotOnEVA(_V(81,-64,1456),_V(0,0,0));
			break;

		case 10:
			Crew.DefineAirLockShape(AirLockStatus,3,7,-66,-62,1453,1457);
			Crew.SetMembersPosRotOnEVA(_V(5,-64,1456),_V(0,0,0));
			break;

		case 11:
			Crew.DefineAirLockShape(AirLockStatus,-73,-69,-66,-62,1453,1457);
			Crew.SetMembersPosRotOnEVA(_V(-71,-64,1456),_V(0,0,0));
			break;

		case 12:
			Crew.DefineAirLockShape(AirLockStatus,-67,-63,-117,-113,1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-65,-115,1598),_V(0,0,0));
			break;

		case 13:
			Crew.DefineAirLockShape(AirLockStatus,-94,-90,-117,-113,1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-92,-115,1598),_V(0,0,0));
			break;

		case 14:
			Crew.DefineAirLockShape(AirLockStatus,-121,-117,-117,-113,1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-119,-115,1598),_V(0,0,0));
			break;

		case 15:
			Crew.DefineAirLockShape(AirLockStatus,-67,-63,-117,-113,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-65,-115,1698),_V(0,0,0));
			break;

		case 16:
			Crew.DefineAirLockShape(AirLockStatus,-94,90,-117,-113,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-92,-115,1698),_V(0,0,0));
			break;

		case 17:
			Crew.DefineAirLockShape(AirLockStatus,-121,-117,-117,-113,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-119,-115,1698),_V(0,0,0));
			break;

		case 18:
			Crew.DefineAirLockShape(AirLockStatus,-67,-63,-164,-160,1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-65,-162.1,1598),_V(0,0,0));
			break;
		
		case 19:
			Crew.DefineAirLockShape(AirLockStatus,-94,-90,-164,-162,-1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-92,-162,1598),_V(0,0,0));
			break;

		case 20:
			Crew.DefineAirLockShape(AirLockStatus,-121,-117,-164,-160,1595,1599);
			Crew.SetMembersPosRotOnEVA(_V(-119,-162,1598),_V(0,0,0));
			break;

		case 21:
			Crew.DefineAirLockShape(AirLockStatus,-67,-63,-164,-160,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-65,-162,1698),_V(0,0,0));
			break;

		case 22:
			Crew.DefineAirLockShape(AirLockStatus,-94,-90,-164,-160,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-92,-162,1698),_V(0,0,0));
			break;

		case 23:
			Crew.DefineAirLockShape(AirLockStatus,-121,-117,-164,-160,1695,1699);
			Crew.SetMembersPosRotOnEVA(_V(-119,-162,1698),_V(0,0,0));
			break;
		}
}

// --------------------------------------------------------------
// Write status to scenario file
// --------------------------------------------------------------
void Explorer::clbkSaveState (FILEHANDLE scn)
{
	char cbuf[256];
	// default vessel parameters
	VESSEL2::clbkSaveState (scn);
	// Save all UMMU member to scenario
	Crew.SaveAllMembersInOrbiterScenarios(scn);
}

// --------------------------------------------------------------
// Read status from scenario file
// --------------------------------------------------------------
void Explorer::clbkLoadStateEx (FILEHANDLE scn, void *vs)
{
char *line;
while (oapiReadScenario_nextline (scn, line))
{
// UMMU, Load all saved member from scenario.
if(Crew.LoadAllMembersFromOrbiterScenario(line)==TRUE)
continue;
ParseScenarioLineEx (line, vs);// unrecognised option - pass to Orbiter's generic parser
}
}




// THIS IS FOR ADDING CREW SEE PDF doc "Allow user to add crew to your ship
// without scenery editor"
bool UMmuCrewAddCallback(void *id, char *str, void *data)
	{
		if(strlen(str)<2||strlen(str)>38)
		return false;
		char *cPtr=(char*)data;if(*cPtr==2){*cPtr=3;strcpy(cPtr+2,str);}
		else if(*cPtr==4){*cPtr=5;strcpy(cPtr+42,str);}
		else if(*cPtr==6){*cPtr=7;strcpy(cPtr+82,str);}return true;
	}
void Explorer::AddUMmuToVessel(BOOL bStartAdding)
{
	if(bStartAdding==FALSE&&cAddUMmuToVessel[0]==0)
	return;
	if(bStartAdding==TRUE){
	int salut=sizeof(cAddUMmuToVessel);
	memset(cAddUMmuToVessel,0,sizeof(cAddUMmuToVessel));
	cAddUMmuToVessel[0]=1;
	}
	else if(cAddUMmuToVessel[0]==1){
	cAddUMmuToVessel[0]=2;
	oapiOpenInputBox ("Enter new crew's name (or escape)",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==3){
	cAddUMmuToVessel[0]=4;
	oapiOpenInputBox ("Enter crew's age",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==5){
	cAddUMmuToVessel[0]=6;
	oapiOpenInputBox ("Enter function (Capt,Sec,Vip,Sci,Doc,Tech,Crew,Pax)",UMmuCrewAddCallback,0,30,(void*)cAddUMmuToVessel);
	}
	else if(cAddUMmuToVessel[0]==7){
	cAddUMmuToVessel[0]=0;
	int Age=max(5,min(100,atoi(&cAddUMmuToVessel[42])));
	if(Crew.AddCrewMember(&cAddUMmuToVessel[2],Age,70,70,&cAddUMmuToVessel[82])==TRUE){
	sprintf(SendHudMessage(),"Crew \"%s\" aged %i added to vessel",&cAddUMmuToVessel[2],Age);
	}
	else{
	strcpy(SendHudMessage(),"ERROR: Crew not added (vessel full?)");
	}
	}
}

void Explorer::clbkPreStep(double simt, double simdt, double mjd)
{
	

}
void Explorer::clbkPostStep(double simt, double simdt, double mjd)
{



	//-----------------------------------------------------
	//Gravity Wheel Animation
	//-----------------------------------------------------
	if (gravwheel_run == 1) //Test - if wheel is supposed to be running, then execute animation based on variable params
	{
		if (gravwheel_speed < 0.016) gravwheel_speed = gravwheel_speed + 0.00001;

		double da = oapiGetSimStep() * gravwheel_speed; 
				

		if (gravwheel_proc >= 1) gravwheel_proc = 0; //Check animation state.  If complete, reset (keep wheel running)
		gravwheel_proc = gravwheel_proc + da; //Increase animation state variable for sim step based on defined wheel speed

		SetAnimation (anim_grav, gravwheel_proc); //Set animation state based on animation state variable value
		
	}
	
	if (gravwheel_run == 0)  //Test - if wheel is supposed to stop, then set state based on animation variable params
	{
		if (gravwheel_speed > 0) gravwheel_speed = gravwheel_speed - 0.00001; 
		double da = oapiGetSimStep() * gravwheel_speed;
		gravwheel_proc = gravwheel_proc + da;
		SetAnimation (anim_grav, gravwheel_proc);
	}




	// The Add Mmu without scenario editor process see PDF doc
	AddUMmuToVessel();

	

	//-----------------------------------------------------
	//Detection of UMMU Event
	//-----------------------------------------------------
	int ReturnCode=Crew.ProcessUniversalMMu();
	switch(ReturnCode)
	{
		case UMMU_TRANSFERED_TO_OUR_SHIP:
			sprintf(SendHudMessage(),"%s \"%s\" aged %i was transfered to our ship",
			Crew.GetCrewMiscIdByName(Crew.GetLastEnteredCrewName()),Crew.GetLastEnteredCrewName()
			,Crew.GetCrewAgeByName(Crew.GetLastEnteredCrewName()));
		break;
		case UMMU_RETURNED_TO_OUR_SHIP:
			sprintf(SendHudMessage(),"%s \"%s\" aged %i entered into our ship",
			Crew.GetCrewMiscIdByName(Crew.GetLastEnteredCrewName()),
			Crew.GetLastEnteredCrewName(),Crew.GetCrewAgeByName(Crew.GetLastEnteredCrewName()));
		break;
	}
	
	//Warn user if UMMU 2.0 not installed or outdated
	Crew.WarnUserUMMUNotInstalled("Explorer");

}



int Explorer::clbkConsumeBufferedKey (DWORD key, bool down, char *kstate)
{
	if (!down) return 0; // only process keydown events	

	if(key==OAPI_KEY_M&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			AddUMmuToVessel(TRUE);
			return 1; 
		}

	
	
		// Ummu Key "E" perform the EVA of the selected member
		//
		if(key==OAPI_KEY_E&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			// PERFORM THE EVA
			int Returned=Crew.EvaCrewMember(Crew.GetCrewNameBySlotNumber(iSelectedUmmuMember));
			// we provide feedback to user (You can display a message on panel or wathewer)
			// here below all the return code possible:
			switch(Returned)
			{
			case TRANSFER_TO_DOCKED_SHIP_OK:
				sprintf(SendHudMessage(),"Transfer to docked ship Ok - %s transfered",
				Crew.GetLastEvaedCrewName());iSelectedUmmuMember=0;
			break;
			case EVA_OK:
				sprintf(SendHudMessage(),"EVA OK - %s left the ship",
				Crew.GetLastEvaedCrewName());iSelectedUmmuMember=0;
			break;
			case ERROR_NO_ONE_ON_BOARD:
				strcpy(SendHudMessage(),"Error, no one on board, unable to EVA");
			break;
			case ERROR_AIRLOCK_CLOSED:
				strcpy(SendHudMessage(),"Error, airlock is closed, unable to EVA");
			break;
			case ERROR_DOCKED_SHIP_HAVE_AIRLOCK_CLOSED:
				strcpy(SendHudMessage(),"Error, docked ship's airlock is closed, unable to transfer");
			break;
			case ERROR_DOCKED_SHIP_IS_FULL:
				strcpy(SendHudMessage(),"Error, docked ship is already full transfer failed");
			break;
			case ERROR_CREW_MEMBER_NOT_FOUND:
				strcpy(SendHudMessage(),"Error, no crew by this name in ship");
			break;
			case ERROR_DOCKEDSHIP_DONOT_USE_UMMU:
				strcpy(SendHudMessage(),"Error, docked ship do not use UMmu 2.0, ask author to add it");
			break;
			case ERROR_MISC_ERROR_EVAFAILED:
				strcpy(SendHudMessage(),"Misc error with UMMU install it again");
			break;
			}	
		return TRUE;
		}
		//---------------------------------------------------------------------------
		// Ummu	Key "1" Select next member This is just internal to the demo
		// you may do your own selection system by panel button, name etc etc
		if(key==OAPI_KEY_1&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			// we test there is someone aboard
			if(Crew.GetCrewTotalNumber()==0)
			{
				strcpy(SendHudMessage(),"Sorry no one aboard unable to select");
				return 1;
			}
			if(iSelectedUmmuMember>0)
				iSelectedUmmuMember--;
				char * Name=Crew.GetCrewNameBySlotNumber(iSelectedUmmuMember);
				sprintf(SendHudMessage(),"Slot %i %s \"%s\" aged %i Selected for EVA or Transfer"
				", please press \"E\" to EVA",iSelectedUmmuMember,
				Crew.GetCrewMiscIdBySlotNumber(iSelectedUmmuMember),Name,
				Crew.GetCrewAgeBySlotNumber(iSelectedUmmuMember));
				return 1;
		}
		//---------------------------------------------------------------------------
		// Ummu Key "2" Select previous member This is just internal to the demo
		// you may do your own selection system by panel button
		if(key==OAPI_KEY_2&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			// we test there is someone aboard
			if(Crew.GetCrewTotalNumber()==0)
			{
				strcpy(SendHudMessage(),"Sorry no one aboard unable to select");
				return 1;
			}
		// we test that we select existing member
		if(iSelectedUmmuMember<Crew.GetCrewTotalNumber()-1)
			iSelectedUmmuMember++;
			char * Name=Crew.GetCrewNameBySlotNumber(iSelectedUmmuMember);
			sprintf(SendHudMessage(),"Slot %i %s \"%s\" aged %i Selected for EVA or Transfer, please press \"E\" to EVA",
			iSelectedUmmuMember,Crew.GetCrewMiscIdBySlotNumber(iSelectedUmmuMember),
			Name,Crew.GetCrewAgeBySlotNumber(iSelectedUmmuMember));
			return 1;
		}

/*		Current configuration sets the airlock door state to always be open when the dock is active.
		This is to simulate that the bay is 'open' and crew enter and leave ships freely.  
		So this section currently commented out.  
		//---------------------------------------------------------------------------
		// Ummu Key "A" Switch the virtual UMMU airlock door on/off
		if(key==OAPI_KEY_A&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			// switch state
			Crew.SetAirlockDoorState(!Crew.GetAirlockDoorState());
			// display state
			if(Crew.GetAirlockDoorState()==TRUE)
				strcpy(SendHudMessage(),"Airlock is now open");
			else
				strcpy(SendHudMessage(),"Airlock is now closed");
			return 1;
		}

*/


		//---------------------------------------------------------------------------
		// Get some infos Name of ship and total soul aboard
		if(key==OAPI_KEY_S)
		{		
			sprintf(SendHudMessage(),"%i souls aboard ship %s",
			Crew.GetCrewTotalNumber(),GetName());
			return 1;
		} 

		// change active dock
		if(key==OAPI_KEY_1&&KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			if(iActiveDockNumber > 0)
			iActiveDockNumber--;
            iActiveDockNumberForHud = iActiveDockNumber + 1;
			 sprintf(SendHudMessage(),"Active dock number changed to: %i",iActiveDockNumberForHud);
			SetUMMUAirlockPos();
			Crew.SetAirlockDoorState(TRUE);

			return 1;
		}
		//---------------------------------------------------------------------------
		// change active dock
		if(key==OAPI_KEY_2&&KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			if(iActiveDockNumber < 23)
			iActiveDockNumber++;
            iActiveDockNumberForHud = iActiveDockNumber + 1;
			 sprintf(SendHudMessage(),"Active dock number changed to: %i",iActiveDockNumberForHud);
			SetUMMUAirlockPos();
			Crew.SetAirlockDoorState(TRUE);
			return 1;
		}

		// Start/Stop the gravity wheel
		if(key==OAPI_KEY_K&&!KEYMOD_SHIFT(kstate)&&!KEYMOD_CONTROL (kstate))
		{
			if (gravwheel_run == 0)
			{
				gravwheel_run = 1;
				PlayVesselWave3(MyID,MYGRAVSTARTSOUND); 
				sprintf(SendHudMessage(), "Initiating Crew Module Rotation");
				return 1;
			}

			if (gravwheel_run == 1)
			{
				gravwheel_run = 0;
				PlayVesselWave3(MyID,MYGRAVSTOPSOUND);
				sprintf(SendHudMessage(), "Stopping Crew Module Rotation");
				return 1;
			}
		}

	
	return 0;
}


bool Explorer::clbkDrawHUD(int mode, const HUDPAINTSPEC *hps, oapi::Sketchpad *skp)
{
	// draw the default HUD
	VESSEL3::clbkDrawHUD (mode, hps, skp);

	// UMmu display messages
	if(dHudMessageDelay>0)
	{
		skp->Text(5,hps->H/60*15,cUmmuHudDisplay,strlen(cUmmuHudDisplay));
	//	dHudMessageDelay-=oapiGetSimStep();
	//	if(dHudMessageDelay<0)
	//		dHudMessageDelay=0;
	}
    return true; 
}

DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel) 
{ 
    return new Explorer (hvessel, flightmodel);
}



DLLCLBK void ovcExit (VESSEL *vessel) 
{ 
    if (vessel) delete (Explorer*)vessel; 
}

void Explorer::clbkPostCreation (void)
{
	MyID=ConnectToOrbiterSoundDLL3(GetHandle());

	RequestLoadVesselWave3(MyID,MYGRAVSTARTSOUND,"Sound\\EASCortez\\GravStart.wav",INTERNAL_ONLY);
	RequestLoadVesselWave3(MyID,MYGRAVSTOPSOUND,"Sound\\EASCortez\\GravStop.wav",INTERNAL_ONLY);

}